@@ -26,6 +26,7 @@
 #include "abstractclipitem.h"
 #include "abstractgroupitem.h"
 #include "titledocument.h"
+#include "kthumb.h"
 
 #include <mlt++/Mlt.h>
 
@@ -36,6 +37,7 @@
 #include <kio/netaccess.h>
 
 #include <QGraphicsItemGroup>
+#include <QtConcurrentRun>
 
 #include <KFileMetaInfo>
 
@@ -43,7 +45,9 @@ ClipManager::ClipManager(KdenliveDoc *doc) :
     QObject(),
     m_audioThumbsQueue(),
     m_doc(doc),
-    m_generatingAudioId()
+    m_generatingAudioId(),
+    m_abortThumb(false),
+    m_closing(false)
 {
     m_clipIdCounter = 1;
     m_folderIdCounter = 1;
@@ -52,18 +56,42 @@ ClipManager::ClipManager(KdenliveDoc *doc) :
     connect(&m_fileWatcher, SIGNAL(deleted(const QString &)), this, SLOT(slotClipMissing(const QString &)));
     connect(&m_fileWatcher, SIGNAL(created(const QString &)), this, SLOT(slotClipAvailable(const QString &)));
     connect(&m_modifiedTimer, SIGNAL(timeout()), this, SLOT(slotProcessModifiedClips()));
+
+#if KDE_IS_VERSION(4,5,0)
+    KImageCache::deleteCache("kdenlive-thumbs");
+    pixmapCache = new KImageCache("kdenlive-thumbs", 1000000);
+    pixmapCache->setEvictionPolicy(KSharedDataCache::EvictOldest);
+#endif
 }
 
 ClipManager::~ClipManager()
 {
+    m_closing = true;
+    m_abortThumb = true;
+    m_thumbsThread.waitForFinished();
+    m_thumbsMutex.lock();
+    m_requestedThumbs.clear();
+    m_thumbsMutex.unlock();
     m_audioThumbsQueue.clear();
     m_generatingAudioId.clear();
+    m_thumbsMutex.lock();
+    m_requestedThumbs.clear();
+    m_thumbsMutex.unlock();
     qDeleteAll(m_clipList);
     m_clipList.clear();
+#if KDE_IS_VERSION(4,5,0)
+    delete pixmapCache;
+#endif
 }
 
 void ClipManager::clear()
 {
+    m_abortThumb = true;
+    m_thumbsThread.waitForFinished();
+    m_thumbsMutex.lock();
+    m_requestedThumbs.clear();
+    m_thumbsMutex.unlock();
+    m_abortThumb = false;
     m_folderList.clear();
     m_audioThumbsQueue.clear();
     m_modifiedClips.clear();
@@ -71,6 +99,60 @@ void ClipManager::clear()
     m_clipList.clear();
     m_clipIdCounter = 1;
     m_folderIdCounter = 1;
+#if KDE_IS_VERSION(4,5,0)
+    pixmapCache->clear();
+#endif
+}
+
+void ClipManager::clearCache()
+{
+#if KDE_IS_VERSION(4,5,0)
+    pixmapCache->clear();
+#endif
+}
+
+void ClipManager::requestThumbs(const QString id, QList <int> frames)
+{
+    m_thumbsMutex.lock();
+    foreach (int frame, frames) {
+        m_requestedThumbs.insertMulti(id, frame);
+    }
+    m_thumbsMutex.unlock();
+    if (!m_thumbsThread.isRunning() && !m_abortThumb) {
+        m_thumbsThread = QtConcurrent::run(this, &ClipManager::slotGetThumbs);
+    }
+}
+
+void ClipManager::stopThumbs(const QString &id)
+{
+    if (m_requestedThumbs.isEmpty() || m_closing) return;
+    m_abortThumb = true;
+    m_thumbsThread.waitForFinished();
+    m_thumbsMutex.lock();
+    m_requestedThumbs.remove(id);
+    m_thumbsMutex.unlock();
+    m_abortThumb = false;
+    if (!m_thumbsThread.isRunning()) {
+        m_thumbsThread = QtConcurrent::run(this, &ClipManager::slotGetThumbs);
+    }
+}
+
+void ClipManager::slotGetThumbs()
+{
+    QMap<QString, int>::iterator i = m_requestedThumbs.begin();
+    while (i != m_requestedThumbs.end() && !m_abortThumb) {
+        QString producerId = i.key();
+        m_thumbsMutex.lock();
+        QList<int> values = m_requestedThumbs.values(producerId);
+        i = m_requestedThumbs.erase(i);
+        m_thumbsMutex.unlock();
+        qSort(values);
+        DocClipBase *clip = getClipById(producerId);
+        if (!clip) continue;
+        while (!values.isEmpty() && clip->thumbProducer() && !m_abortThumb) {
+            clip->thumbProducer()->getThumb(values.takeFirst());
+        }
+    }
 }
 
 void ClipManager::checkAudioThumbs()
@@ -215,10 +297,12 @@ const QList <DocClipBase *> ClipManager::getClipByResource(QString resource)
 {
     QList <DocClipBase *> list;
     QString clipResource;
+    QString proxyResource;
     for (int i = 0; i < m_clipList.count(); i++) {
         clipResource = m_clipList.at(i)->getProperty("resource");
+        proxyResource = m_clipList.at(i)->getProperty("proxy");
         if (clipResource.isEmpty()) clipResource = m_clipList.at(i)->getProperty("colour");
-        if (clipResource == resource) {
+        if (clipResource == resource || proxyResource == resource) {
             list.append(m_clipList.at(i));
         }
     }
@@ -233,27 +317,26 @@ void ClipManager::clearUnusedProducers()
     }
 }
 
-void ClipManager::resetProducersList(const QList <Mlt::Producer *> prods)
+void ClipManager::resetProducersList(const QList <Mlt::Producer *> prods, bool displayRatioChanged, bool fpsChanged)
 {
     for (int i = 0; i < m_clipList.count(); i++) {
-        if (m_clipList.at(i)->numReferences() > 0) {
-            m_clipList.at(i)->clearProducers();
+        if (m_clipList.at(i)->numReferences() > 0 || displayRatioChanged || fpsChanged) {
+            m_clipList.at(i)->deleteProducers();
         }
     }
     QString id;
     for (int i = 0; i < prods.count(); i++) {
         id = prods.at(i)->get("id");
-        kDebug() << "// // // REPLACE CLIP: " << id;
         if (id.contains('_')) id = id.section('_', 0, 0);
         DocClipBase *clip = getClipById(id);
         if (clip) {
-            clip->setProducer(prods.at(i));
+            clip->setProducer(prods.at(i), false, true);
         }
     }
-    emit checkAllClips();
+    emit checkAllClips(displayRatioChanged, fpsChanged);
 }
 
-void ClipManager::slotAddClipList(const KUrl::List urls, const QString group, const QString &groupId)
+void ClipManager::slotAddClipList(const KUrl::List urls, const QString &group, const QString &groupId)
 {
     QUndoCommand *addClips = new QUndoCommand();
 
@@ -329,12 +412,12 @@ void ClipManager::slotAddClipList(const KUrl::List urls, const QString group, co
     }
 }
 
-void ClipManager::slotAddClipFile(const KUrl url, const QString group, const QString &groupId)
+void ClipManager::slotAddClipFile(const KUrl &url, const QString &group, const QString &groupId)
 {
     slotAddClipList(KUrl::List(url), group, groupId);
 }
 
-void ClipManager::slotAddXmlClipFile(const QString name, const QDomElement xml, const QString group, const QString &groupId)
+void ClipManager::slotAddXmlClipFile(const QString &name, const QDomElement &xml, const QString &group, const QString &groupId)
 {
     QDomDocument doc;
     doc.appendChild(doc.importNode(xml, true));
@@ -351,7 +434,7 @@ void ClipManager::slotAddXmlClipFile(const QString name, const QDomElement xml,
     m_doc->commandStack()->push(command);
 }
 
-void ClipManager::slotAddColorClipFile(const QString name, const QString color, QString duration, const QString group, const QString &groupId)
+void ClipManager::slotAddColorClipFile(const QString &name, const QString &color, QString duration, const QString &group, const QString &groupId)
 {
     QDomDocument doc;
     QDomElement prod = doc.createElement("producer");
@@ -372,10 +455,10 @@ void ClipManager::slotAddColorClipFile(const QString name, const QString color,
     m_doc->commandStack()->push(command);
 }
 
-void ClipManager::slotAddSlideshowClipFile(const QString name, const QString path, int count, const QString duration,
+void ClipManager::slotAddSlideshowClipFile(const QString &name, const QString &path, int count, const QString &duration,
         const bool loop, const bool crop, const bool fade,
         const QString &luma_duration, const QString &luma_file, const int softness,
-        const QString &animation, QString group, const QString &groupId)
+        const QString &animation, const QString &group, const QString &groupId)
 {
     QDomDocument doc;
     QDomElement prod = doc.createElement("producer");
@@ -405,7 +488,7 @@ void ClipManager::slotAddSlideshowClipFile(const QString name, const QString pat
 
 
 
-void ClipManager::slotAddTextClipFile(const QString titleName, int out, const QString xml, const QString group, const QString &groupId)
+void ClipManager::slotAddTextClipFile(const QString &titleName, int out, const QString &xml, const QString &group, const QString &groupId)
 {
     QDomDocument doc;
     QDomElement prod = doc.createElement("producer");
@@ -427,7 +510,7 @@ void ClipManager::slotAddTextClipFile(const QString titleName, int out, const QS
     m_doc->commandStack()->push(command);
 }
 
-void ClipManager::slotAddTextTemplateClip(QString titleName, const KUrl path, const QString group, const QString &groupId)
+void ClipManager::slotAddTextTemplateClip(QString titleName, const KUrl &path, const QString &group, const QString &groupId)
 {
     QDomDocument doc;
     QDomElement prod = doc.createElement("producer");
