@@ -30,11 +30,19 @@
 #include <QPixmap>
 #include <QObject>
 #include <QTimer>
+#include <QMutex>
+#include <QFuture>
 
 #include <KUrl>
 #include <KUndoStack>
 #include <KDirWatch>
 #include <klocale.h>
+#include <kdeversion.h>
+
+#if KDE_IS_VERSION(4,5,0)
+#include <KImageCache>
+#endif
+
 
 #include "gentime.h"
 #include "definitions.h"
@@ -64,22 +72,22 @@ Q_OBJECT public:
      * @param url file to add
      * @param group name of the group to insert the file in (can be empty)
      * @param groupId id of the group (if any) */
-    void slotAddClipFile(const KUrl url, const QString group, const QString &groupId);
+    void slotAddClipFile(const KUrl &url, const QString &group, const QString &groupId);
 
     /** @brief Adds a list of files to the project.
      * @param urls files to add
      * @param group name of the group to insert the files in (can be empty)
      * @param groupId id of the group (if any)
      * It checks for duplicated items and asks to the user for instructions. */
-    void slotAddClipList(const KUrl::List urls, const QString group, const QString &groupId);
-    void slotAddTextClipFile(const QString titleName, int out, const QString xml, const QString group, const QString &groupId);
-    void slotAddTextTemplateClip(QString titleName, const KUrl path, const QString group, const QString &groupId);
-    void slotAddXmlClipFile(const QString name, const QDomElement xml, const QString group, const QString &groupId);
-    void slotAddColorClipFile(const QString name, const QString color, QString duration, const QString group, const QString &groupId);
-    void slotAddSlideshowClipFile(const QString name, const QString path, int count, const QString duration,
+    void slotAddClipList(const KUrl::List urls, const QString &group, const QString &groupId);
+    void slotAddTextClipFile(const QString &titleName, int out, const QString &xml, const QString &group, const QString &groupId);
+    void slotAddTextTemplateClip(QString titleName, const KUrl &path, const QString &group, const QString &groupId);
+    void slotAddXmlClipFile(const QString &name, const QDomElement &xml, const QString &group, const QString &groupId);
+    void slotAddColorClipFile(const QString &name, const QString &color, QString duration, const QString &group, const QString &groupId);
+    void slotAddSlideshowClipFile(const QString &name, const QString &path, int count, const QString &duration,
                                   const bool loop, const bool crop,const bool fade,
                                   const QString &luma_duration, const QString &luma_file, const int softness,
-                                  const QString &animation, const QString group, const QString &groupId);
+                                  const QString &animation, const QString &group, const QString &groupId);
     DocClipBase *getClipById(QString clipId);
     const QList <DocClipBase *> getClipByResource(QString resource);
     void slotDeleteClips(QStringList ids);
@@ -95,14 +103,23 @@ Q_OBJECT public:
     void askForAudioThumb(const QString &id);
     QString projectFolder() const;
     void clearUnusedProducers();
-    void resetProducersList(const QList <Mlt::Producer *> prods);
+    void resetProducersList(const QList <Mlt::Producer *> prods, bool displayRatioChanged, bool fpsChanged);
     void addFolder(const QString&, const QString&);
     void deleteFolder(const QString&);
     void clear();
+    void clearCache();
     AbstractGroupItem *createGroup();
     void removeGroup(AbstractGroupItem *group);
     QDomElement groupsXml() const;
     int clipsCount() const;
+    /** @brief Request creation of a clip thumbnail for specified frames. */
+    void requestThumbs(const QString id, QList <int> frames);
+    /** @brief remove a clip id from the queue list. */
+    void stopThumbs(const QString &id);
+
+#if KDE_IS_VERSION(4,5,0)
+    KImageCache* pixmapCache;
+#endif
 
 private slots:
     /** A clip was externally modified, monitor for more changes and prepare for reload */
@@ -111,6 +128,7 @@ private slots:
     void slotClipAvailable(const QString &path);
     /** Check the list of externally modified clips, and process them if they were not modified in the last 1500 milliseconds */
     void slotProcessModifiedClips();
+    void slotGetThumbs();
 
 private:   // Private attributes
     /** the list of clips in the document */
@@ -129,13 +147,21 @@ private:   // Private attributes
     QTimer m_modifiedTimer;
     /** List of the clip IDs that need to be reloaded after being externally modified */
     QMap <QString, QTime> m_modifiedClips;
+    /** Struct containing the list of clip thumbnails to request (clip id and frames) */
+    QMap <QString, int> m_requestedThumbs;
+    QMutex m_thumbsMutex;
+    QFuture<void> m_thumbsThread;
+    /** @brief If true, abort processing of clip thumbs before removing a clip. */
+    bool m_abortThumb;
+    /** @brief We are about to delete the clip producer, stop processing thumbs. */
+    bool m_closing;
 
 signals:
     void reloadClip(const QString &);
     void modifiedClip(const QString &);
     void missingClip(const QString &);
     void availableClip(const QString &);
-    void checkAllClips();
+    void checkAllClips(bool displayRatioChanged, bool fpsChanged);
 };
 
 #endif
