@@ -269,7 +269,6 @@ ClipProperties::ClipProperties(DocClipBase *clip, Timecode tc, double fps, QWidg
         m_view.clip_color->setColor(QColor('#' + props.value("colour").right(8).left(6)));
         connect(m_view.clip_color, SIGNAL(changed(QColor)), this, SLOT(slotModified()));
     } else if (t == SLIDESHOW) {
-        bool isMime = true;
         if (url.fileName().startsWith(".all.")) {
             // the image sequence is defined by mimetype
             m_view.clip_path->setText(url.directory());
@@ -278,7 +277,6 @@ ClipProperties::ClipProperties(DocClipBase *clip, Timecode tc, double fps, QWidg
             m_view.slide_type_label->setHidden(true);
             m_view.image_type->setHidden(true);
             m_view.clip_path->setText(url.path());
-            isMime = false;
         }
 
         m_view.tabWidget->removeTab(METATAB);
@@ -711,6 +709,7 @@ const QString &ClipProperties::clipId() const
 QMap <QString, QString> ClipProperties::properties()
 {
     QMap <QString, QString> props;
+    QLocale locale;
     CLIPTYPE t = UNKNOWN;
     if (m_clip != NULL) {
         t = m_clip->clipType();
@@ -741,7 +740,7 @@ QMap <QString, QString> ClipProperties::properties()
     double fps = m_view.clip_framerate->value();
     if (m_view.clip_force_framerate->isChecked()) {
         if (fps != m_old_props.value("force_fps").toDouble()) {
-            props["force_fps"] = QString::number(fps);
+            props["force_fps"] = locale.toString(fps);
             m_clipNeedsRefresh = true;
         }
     } else if (m_old_props.contains("force_fps") && !m_old_props.value("force_fps").isEmpty()) {
@@ -1022,10 +1021,8 @@ void ClipProperties::slotUpdateDurationFormat(int ix)
 void ClipProperties::slotDeleteProxy()
 {
       QString proxy = m_clip->getProperty("proxy");
-      QFile::remove(proxy);
-      QMap <QString, QString> props;
-      props.insert("proxy", QString());
-      emit applyNewClipProperties(m_clip->getId(), m_clip->properties(), props, false, true);
+      if (proxy.isEmpty()) return;
+      emit deleteProxy(proxy);
       if (m_proxyContainer) delete m_proxyContainer;
 }
 
