@@ -27,11 +27,12 @@
 
 
 ClipTranscode::ClipTranscode(KUrl::List urls, const QString &params, const QString &description, QWidget * parent) :
-        QDialog(parent), m_urls(urls)
+        QDialog(parent), m_urls(urls), m_duration(0)
 {
     setFont(KGlobalSettings::toolBarFont());
     setupUi(this);
     setAttribute(Qt::WA_DeleteOnClose);
+    log_text->setHidden(true);
     setWindowTitle(i18n("Transcode Clip"));
     auto_add->setText(i18np("Add clip to project", "Add clips to project", m_urls.count()));
 
@@ -85,7 +86,7 @@ ClipTranscode::ClipTranscode(KUrl::List urls, const QString &params, const QStri
     connect(&m_transcodeProcess, SIGNAL(readyReadStandardOutput()), this, SLOT(slotShowTranscodeInfo()));
     connect(&m_transcodeProcess, SIGNAL(finished(int, QProcess::ExitStatus)), this, SLOT(slotTranscodeFinished(int, QProcess::ExitStatus)));
 
-    //adjustSize();
+    adjustSize();
 }
 
 ClipTranscode::~ClipTranscode()
@@ -100,6 +101,7 @@ void ClipTranscode::slotStartTransCode()
     if (m_transcodeProcess.state() != QProcess::NotRunning) {
         return;
     }
+    m_duration = 0;
     QStringList parameters;
     QString destination;
     QString params = ffmpeg_params->toPlainText().simplified();
@@ -136,6 +138,30 @@ void ClipTranscode::slotStartTransCode()
 void ClipTranscode::slotShowTranscodeInfo()
 {
     QString log = QString(m_transcodeProcess.readAll());
+    int progress;
+    if (m_duration == 0) {
+        if (log.contains("Duration:")) {
+            QString data = log.section("Duration:", 1, 1).section(',', 0, 0).simplified();
+            QStringList numbers = data.split(':');
+            m_duration = numbers.at(0).toInt() * 3600 + numbers.at(1).toInt() * 60 + numbers.at(2).toDouble();
+            log_text->setHidden(true);
+            job_progress->setHidden(false);
+        }
+        else {
+            log_text->setHidden(false);
+            job_progress->setHidden(true);
+        }
+    }
+    else if (log.contains("time=")) {
+        QString time = log.section("time=", 1, 1).simplified().section(' ', 0, 0);
+        if (time.contains(':')) {
+            QStringList numbers = time.split(':');
+            progress = numbers.at(0).toInt() * 3600 + numbers.at(1).toInt() * 60 + numbers.at(2).toDouble();
+        }
+        else progress = (int) time.toDouble();
+        kDebug()<<"// PROGRESS: "<<progress<<", "<<m_duration;
+        job_progress->setValue((int) (100.0 * progress / m_duration));
+    }
     //kDebug() << "//LOG: " << log;
     log_text->setPlainText(log);
 }
@@ -144,6 +170,7 @@ void ClipTranscode::slotTranscodeFinished(int exitCode, QProcess::ExitStatus exi
 {
     buttonBox->button(QDialogButtonBox::Abort)->setText(i18n("Close"));
     button_start->setEnabled(true);
+    m_duration = 0;
 
     if (exitCode == 0 && exitStatus == QProcess::NormalExit) {
         log_text->setHtml(log_text->toPlainText() + "<br /><b>" + i18n("Transcoding finished."));
