@@ -21,7 +21,7 @@
 #ifndef CUSTOMTRACKVIEW_H
 #define CUSTOMTRACKVIEW_H
 
-#include <KPixmapCache>
+#include <kdeversion.h>
 #include <KColorScheme>
 
 #include <QGraphicsView>
@@ -43,7 +43,6 @@ class AbstractClipItem;
 class AbstractGroupItem;
 class Transition;
 
-
 class CustomTrackView : public QGraphicsView
 {
     Q_OBJECT
@@ -61,16 +60,16 @@ public:
     void configTracks(QList <TrackInfo> trackInfos);
     int cursorPos();
     void checkAutoScroll();
-    void moveClip(const ItemInfo start, const ItemInfo end, bool refresh);
-    void moveGroup(QList <ItemInfo> startClip, QList <ItemInfo> startTransition, const GenTime offset, const int trackOffset, bool reverseMove = false);
+    void moveClip(const ItemInfo &start, const ItemInfo &end, bool refresh);
+    void moveGroup(QList <ItemInfo> startClip, QList <ItemInfo> startTransition, const GenTime &offset, const int trackOffset, bool reverseMove = false);
     /** move transition, startPos = (old start, old end), endPos = (new start, new end) */
-    void moveTransition(const ItemInfo start, const ItemInfo end, bool m_refresh);
-    void resizeClip(const ItemInfo start, const ItemInfo end, bool dontWorry = false);
+    void moveTransition(const ItemInfo &start, const ItemInfo &end, bool refresh);
+    void resizeClip(const ItemInfo &start, const ItemInfo &end, bool dontWorry = false);
     void addClip(QDomElement xml, const QString &clipId, ItemInfo info, EffectsList list = EffectsList(), bool overwrite = false, bool push = false, bool refresh = true);
     void deleteClip(ItemInfo info, bool refresh = true);
     void slotDeleteClipMarker(const QString &comment, const QString &id, const GenTime &position);
     void slotDeleteAllClipMarkers(const QString &id);
-    void addMarker(const QString &id, const GenTime &pos, const QString comment);
+    void addMarker(const QString &id, const GenTime &pos, const QString &comment);
     void setScale(double scaleFactor, double verticalScale);
     void deleteClip(const QString &clipId);
     void slotAddEffect(QDomElement effect, GenTime pos, int track);
@@ -89,14 +88,15 @@ public:
     /** @brief Cuts all clips that are selected at the timeline cursor position. */
     void cutSelectedClips();
     void setContextMenu(QMenu *timeline, QMenu *clip, QMenu *transition, QActionGroup *clipTypeGroup, QMenu *markermenu);
-    void checkTrackHeight();
+    bool checkTrackHeight();
+    void updateSceneFrameWidth();
     //QList <TrackInfo> tracksList() const;
     void setTool(PROJECTTOOL tool);
     ClipItem *cutClip(ItemInfo info, GenTime cutTime, bool cut, bool execute = true);
     void slotSeekToPreviousSnap();
     void slotSeekToNextSnap();
     double getSnapPointForPos(double pos);
-    void editKeyFrame(const GenTime pos, const int track, const int index, const QString keyframes);
+    void editKeyFrame(const GenTime &pos, const int track, const int index, const QString &keyframes);
     bool findString(const QString &text);
     void selectFound(QString track, QString pos);
     bool findNextString(const QString &text);
@@ -118,12 +118,11 @@ public:
     void slotInsertSpace();
     /** @brief Prepares removing space. */
     void slotRemoveSpace();
-    void insertSpace(QList<ItemInfo> clipsToMove, QList<ItemInfo> transToMove, int track, const GenTime duration, const GenTime offset);
+    void insertSpace(QList<ItemInfo> clipsToMove, QList<ItemInfo> transToMove, int track, const GenTime &duration, const GenTime &offset);
     ClipItem *getActiveClipUnderCursor(bool allowOutsideCursor = false) const;
     void deleteTimelineTrack(int ix, TrackInfo trackinfo);
     void saveThumbnails();
     void autoTransition();
-    QStringList getLadspaParams(QDomElement effect) const;
     void initCursorPos(int pos);
 
     /** @brief Locks or unlocks a track.
@@ -135,7 +134,7 @@ public:
     void lockTrack(int ix, bool lock, bool requestUpdate = true);
     void groupClips(bool group = true);
     void doGroupClips(QList <ItemInfo> clipInfos, QList <ItemInfo> transitionInfos, bool group);
-    void loadGroups(const QDomNodeList groups);
+    void loadGroups(const QDomNodeList &groups);
 
     /** @brief Creates SplitAudioCommands for selected clips. */
     void splitAudio();
@@ -144,7 +143,7 @@ public:
     * @param pos Position of the clip to split
     * @param track Track of the clip
     * @param split Split or unsplit */
-    void doSplitAudio(const GenTime &pos, int track, bool split);
+    void doSplitAudio(const GenTime &pos, int track, EffectsList effects, bool split);
     void setVideoOnly();
     void setAudioOnly();
     void setAudioAndVideo();
@@ -156,6 +155,8 @@ public:
     int selectedTrack() const;
     QStringList selectedClips() const;
     QList<ClipItem *> selectedClipItems() const;
+    /** @brief Checks wheter an item can be inserted (make sure it does not overlap another item) */
+    bool canBePastedTo(ItemInfo info, int type) const;
 
     /** @brief Selects a clip.
     * @param add Whether to select or deselect
@@ -177,7 +178,6 @@ public:
     void clearSelection();
     void editItemDuration();
     void buildGuidesMenu(QMenu *goMenu) const;
-    KPixmapCache* m_pixmapCache;
     /** update the timeline objects when palette changes */
     void updatePalette();
     /** @brief Returns true if a track has audio data on it.
@@ -186,6 +186,8 @@ public:
     * Check whether given track has a clip with audio in it. */
     bool hasAudio(int track) const;
 
+    int getFrameWidth();
+    
 public slots:
     void setCursorPos(int pos, bool seek = true);
     void moveCursorPos(int delta);
@@ -210,7 +212,7 @@ public slots:
      * @param t Position of the marker
      * @param c Comment of the marker */
     void slotAddClipMarker(const QString &id, GenTime t, QString c);
-    bool addGuide(const GenTime pos, const QString &comment);
+    bool addGuide(const GenTime &pos, const QString &comment);
 
     /** @brief Shows a dialog for adding a guide.
      * @param dialog (default = true) false = do not show the dialog but use current position as position and comment */
@@ -219,7 +221,7 @@ public slots:
     void slotEditGuide(int guidePos = -1);
     void slotDeleteGuide(int guidePos = -1);
     void slotDeleteAllGuides();
-    void editGuide(const GenTime oldPos, const GenTime pos, const QString &comment);
+    void editGuide(const GenTime &oldPos, const GenTime &pos, const QString &comment);
     void copyClip();
     void pasteClip();
     void pasteClipEffects();
@@ -232,7 +234,7 @@ public slots:
     void slotDeleteTrack(int ix);
     /** @brief Shows the configure tracks dialog. */
     void slotConfigTracks(int ix);
-    void clipNameChanged(const QString id, const QString name);
+    void clipNameChanged(const QString &id, const QString &name);
     void slotTrackUp();
     void slotTrackDown();
     void slotSelectTrack(int ix);
@@ -260,7 +262,7 @@ public slots:
     /** @brief Add en effect to a track.
     * @param effect The new effect xml
     * @param ix The track index */
-    void slotAddTrackEffect(const QDomElement effect, int ix);
+    void slotAddTrackEffect(const QDomElement &effect, int ix);
 
     /** @brief Update the list of snap points (sticky timeline hotspots).
     * @param selected The currently selected clip if any
@@ -282,6 +284,7 @@ protected:
     virtual Qt::DropActions supportedDropActions() const;
 
 private:
+    int m_ct;
     int m_tracksHeight;
     int m_projectDuration;
     int m_cursorPos;
@@ -357,8 +360,7 @@ private:
     /** Get the index of the video track that is just below current track */
     int getPreviousVideoTrack(int track);
     void updatePositionEffects(ClipItem * item, ItemInfo info, bool standalone = true);
-    bool insertDropClips(const QMimeData *data, const QPoint pos);
-    bool canBePastedTo(ItemInfo info, int type) const;
+    bool insertDropClips(const QMimeData *data, const QPoint &pos);
     bool canBePastedTo(QList <ItemInfo> infoList, int type) const;
     bool canBePasted(QList<AbstractClipItem *> items, GenTime offset, int trackOffset) const;
     bool canBeMoved(QList<AbstractClipItem *> items, GenTime offset, int trackOffset) const;
@@ -411,12 +413,7 @@ private:
     void razorGroup(AbstractGroupItem *group, GenTime cutPos);
 
     /** @brief Gets the effect parameters that will be passed to Mlt. */
-    EffectsParameterList getEffectArgs(const QDomElement effect);
-
-    /** @brief Updates @param item's pan and zoom effect after resize or cut.
-     * @param item clip whose pan and zoom effect should be updated
-     * @param cutPos (optional) if clip was cut, cut position relative to the original's clip position */
-    void updatePanZoom(ClipItem *item, GenTime cutPos = GenTime());
+    EffectsParameterList getEffectArgs(const QDomElement &effect);
 
     /** @brief Update Tracknames to fit again after track was added/deleted.
      * @param track Number of track which was added/deleted
@@ -470,7 +467,7 @@ signals:
     void activateDocumentMonitor();
     void trackHeightChanged();
     void tracksChanged();
-    void displayMessage(const QString, MessageType);
+    void displayMessage(const QString &, MessageType);
     void showClipFrame(DocClipBase *, QPoint, const int);
     void doTrackLock(int, bool);
     void updateClipMarkers(DocClipBase *);
