@@ -87,35 +87,19 @@ DocClipBase::DocClipBase(ClipManager *clipManager, QDomElement xml, const QStrin
 
     if (!m_properties.contains("name")) m_properties.insert("name", url.fileName());
 
-    //if (!url.isEmpty() && QFile::exists(url.path()))
-    {
-        m_thumbProd = new KThumb(clipManager, url, m_id, m_properties.value("file_hash"));
-        if (m_clipType == AV || m_clipType == AUDIO || m_clipType == PLAYLIST) slotCreateAudioTimer();
-    }
-    //kDebug() << "type is video" << (m_clipType == AV) << " " << m_clipType;
+    m_thumbProd = new KThumb(clipManager, url, m_id, m_properties.value("file_hash"));
+    if (m_clipType == AV || m_clipType == AUDIO || m_clipType == PLAYLIST) slotCreateAudioTimer();
 }
 
-/*DocClipBase & DocClipBase::operator=(const DocClipBase & clip) {
-    DocClipBase::operator=(clip);
-    m_id = clip.getId();
-    m_clipType = clip.clipType();
-    m_name = clip.name();
-    m_duration = clip.duration();
-    m_audioThumbCreated = clip.audioThumbCreated();
-    m_properties = clip.properties();
-    return *this;
-}*/
-
 DocClipBase::~DocClipBase()
 {
-    kDebug() << "CLIP " << m_id << " DELETED******************************";
     delete m_thumbProd;
     if (m_audioTimer) {
         m_audioTimer->stop();
         delete m_audioTimer;
     }
-    /*kDebug() <<" * * *CNT "<<m_baseTrackProducers.count();
-    if (m_baseTrackProducers.count() > 0) kDebug()<<"YOYO: "<<m_baseTrackProducers.at(0)->get_out()<<", CUT: "<<m_baseTrackProducers.at(0)->is_cut();*/
+    qDeleteAll(m_toDeleteProducers);
+    m_toDeleteProducers.clear();
     qDeleteAll(m_baseTrackProducers);
     m_baseTrackProducers.clear();
     qDeleteAll(m_audioTrackProducers);
@@ -138,7 +122,7 @@ QPoint DocClipBase::zone() const
 
 void DocClipBase::slotCreateAudioTimer()
 {
-    connect(m_thumbProd, SIGNAL(audioThumbReady(QMap <int, QMap <int, QByteArray> >)), this , SLOT(updateAudioThumbnail(QMap <int, QMap <int, QByteArray> >)));
+    connect(m_thumbProd, SIGNAL(audioThumbReady(const audioByteArray&)), this , SLOT(updateAudioThumbnail(const audioByteArray&)));
     m_audioTimer = new QTimer(this);
     connect(m_audioTimer, SIGNAL(timeout()), this, SLOT(slotGetAudioThumbs()));
 }
@@ -181,11 +165,6 @@ const QString &DocClipBase::getId() const
     return m_id;
 }
 
-void DocClipBase::setId(const QString &newId)
-{
-    m_id = newId;
-}
-
 const CLIPTYPE & DocClipBase::clipType() const
 {
     return m_clipType;
@@ -227,7 +206,7 @@ bool DocClipBase::isTransparent() const
     return (m_properties.value("transparency") == "1");
 }
 
-const QString DocClipBase::getProperty(const QString prop) const
+const QString DocClipBase::getProperty(const QString &prop) const
 {
     return m_properties.value(prop);
 }
@@ -304,7 +283,7 @@ const QPixmap & DocClipBase::thumbnail() const
     return m_thumbnail;
 }
 
-void DocClipBase::updateAudioThumbnail(QMap<int, QMap<int, QByteArray> > data)
+void DocClipBase::updateAudioThumbnail(const audioByteArray& data)
 {
     //kDebug() << "CLIPBASE RECIEDVED AUDIO DATA*********************************************";
     m_audioFrameCache = data;
@@ -429,34 +408,60 @@ QString DocClipBase::markerComment(GenTime t)
     return QString();
 }
 
-void DocClipBase::clearProducers()
+void DocClipBase::clearThumbProducer()
 {
-    m_baseTrackProducers.clear();
+    if (m_thumbProd) m_thumbProd->clearProducer();
 }
 
-void DocClipBase::deleteProducers(bool clearThumbCreator)
+void DocClipBase::deleteProducers()
 {
-    kDebug() << "// CLIP KILL PRODS ct: " << m_baseTrackProducers.count();
-    if (clearThumbCreator && m_thumbProd) m_thumbProd->clearProducer();
-    /*kDebug()<<"// CLIP KILL PRODS ct: "<<m_baseTrackProducers.count();
-    int max = m_baseTrackProducers.count();
-    for (int i = 0; i < max; i++) {
-        kDebug()<<"// CLIP KILL PROD "<<i;
-    Mlt::Producer *p = m_baseTrackProducers.takeAt(i);
-    if (p != NULL) {
-     delete p;
-     p = NULL;
+    if (m_thumbProd) m_thumbProd->clearProducer();
+    
+    if (numReferences() > 0) {
+        // Clip is used in timeline, delay producers deletion
+        if (m_videoOnlyProducer) m_toDeleteProducers.append(m_videoOnlyProducer);
+        for (int i = 0; i < m_baseTrackProducers.count(); i++) {
+            m_toDeleteProducers.append(m_baseTrackProducers.at(i));
+        }
+        for (int i = 0; i < m_audioTrackProducers.count(); i++) {
+            m_toDeleteProducers.append(m_audioTrackProducers.at(i));
+        }
     }
-    m_baseTrackProducers.insert(i, NULL);
+    else {
+        delete m_videoOnlyProducer;
+        qDeleteAll(m_baseTrackProducers);
+        qDeleteAll(m_audioTrackProducers);
+        m_replaceMutex.unlock();
+    }
+    m_videoOnlyProducer = NULL;
+    m_baseTrackProducers.clear();
+    m_audioTrackProducers.clear();
+}
+
+void DocClipBase::cleanupProducers()
+{
+    /*
+    int ct = 0;
+    kDebug()<<"----------------------------------------------------------------------------------";
+    for (int i = 0; i < m_toDeleteProducers.count(); i++) {
+        if (m_toDeleteProducers.at(i) != NULL) {
+            Mlt::Properties props(m_toDeleteProducers.at(i)->get_properties());
+            if (props.ref_count() > 2) {
+                kDebug()<<"PRODUCER: "<<i<<", COUNTS: "<<props.ref_count();
+                //exit(1);
+            }
+            ct++;
+        }
     }*/
 
-    delete m_videoOnlyProducer;
-    m_videoOnlyProducer = NULL;
+    qDeleteAll(m_toDeleteProducers);
+    m_toDeleteProducers.clear();
+    m_replaceMutex.unlock();
+}
 
-    qDeleteAll(m_baseTrackProducers);
-    m_baseTrackProducers.clear();
-    qDeleteAll(m_audioTrackProducers);
-    m_audioTrackProducers.clear();
+bool DocClipBase::isClean() const
+{
+    return m_toDeleteProducers.isEmpty();
 }
 
 void DocClipBase::setValid()
@@ -464,16 +469,30 @@ void DocClipBase::setValid()
     m_placeHolder = false;
 }
 
-void DocClipBase::setProducer(Mlt::Producer *producer, bool reset)
+void DocClipBase::setProducer(Mlt::Producer *producer, bool reset, bool readPropertiesFromProducer)
 {
-    if (producer == NULL || (m_placeHolder && !reset)) return;
-    if (m_thumbProd && (reset || !m_thumbProd->hasProducer())) m_thumbProd->setProducer(producer);
+    if (producer == NULL) return;
     if (reset) {
-        // Clear all previous producers
-        kDebug() << "/+++++++++++++++   DELETE ALL PRODS " << producer->get("id");
-        deleteProducers(false);
+        QMutexLocker locker(&m_producerMutex);
+        m_replaceMutex.lock();
+        deleteProducers();
     }
     QString id = producer->get("id");
+    if (m_placeHolder || !producer->is_valid()) {
+        char *tmp = qstrdup(i18n("Missing clip").toUtf8().constData());
+        producer->set("markup", tmp);
+        producer->set("bgcolour", "0xff0000ff");
+        producer->set("pad", "10");
+        delete[] tmp;
+    }
+    else if (m_thumbProd && !m_thumbProd->hasProducer()) {
+        if (m_clipType != AUDIO) {
+            if (!id.endsWith("_audio"))
+                m_thumbProd->setProducer(producer);
+        }
+        else m_thumbProd->setProducer(producer);
+    }
+    bool updated = false;
     if (id.contains('_')) {
         // this is a subtrack producer, insert it at correct place
         id = id.section('_', 1);
@@ -484,10 +503,18 @@ void DocClipBase::setProducer(Mlt::Producer *producer, bool reset)
                     m_audioTrackProducers.append(NULL);
                 }
             }
-            if (m_audioTrackProducers.at(pos) == NULL) m_audioTrackProducers[pos] = producer;
+            if (m_audioTrackProducers.at(pos) == NULL) {
+                m_audioTrackProducers[pos] = producer;
+                updated = true;
+            }
+            else delete producer;
             return;
         } else if (id.endsWith("video")) {
-            m_videoOnlyProducer = producer;
+            if (m_videoOnlyProducer == NULL) {
+                m_videoOnlyProducer = producer;
+                updated = true;
+            }
+            else delete producer;
             return;
         }
         int pos = id.toInt();
@@ -496,13 +523,24 @@ void DocClipBase::setProducer(Mlt::Producer *producer, bool reset)
                 m_baseTrackProducers.append(NULL);
             }
         }
-        if (m_baseTrackProducers.at(pos) == NULL) m_baseTrackProducers[pos] = producer;
+        if (m_baseTrackProducers.at(pos) == NULL) {
+            m_baseTrackProducers[pos] = producer;
+            updated = true;
+        }
+        else delete producer;
     } else {
-        if (m_baseTrackProducers.isEmpty()) m_baseTrackProducers.append(producer);
-        else if (m_baseTrackProducers.at(0) == NULL) m_baseTrackProducers[0] = producer;
+        if (m_baseTrackProducers.isEmpty()) {
+            m_baseTrackProducers.append(producer);
+            updated = true;
+        }
+        else if (m_baseTrackProducers.at(0) == NULL) {
+            m_baseTrackProducers[0] = producer;
+            updated = true;
+        }
+        else delete producer;
     }
-    //m_clipProducer = producer;
-    //m_clipProducer->set("transparency", m_properties.value("transparency").toInt());
+    if (updated && readPropertiesFromProducer && (m_clipType != COLOR && m_clipType != IMAGE && m_clipType != TEXT))
+        setDuration(GenTime(producer->get_length(), KdenliveSettings::project_fps()));
 }
 
 static double getPixelAspect(QMap<QString, QString>& props) {
@@ -518,62 +556,121 @@ static double getPixelAspect(QMap<QString, QString>& props) {
 
 Mlt::Producer *DocClipBase::audioProducer(int track)
 {
+    QMutexLocker locker(&m_producerMutex);
     if (m_audioTrackProducers.count() <= track) {
         while (m_audioTrackProducers.count() - 1 < track) {
             m_audioTrackProducers.append(NULL);
         }
     }
     if (m_audioTrackProducers.at(track) == NULL) {
-        Mlt::Producer *base = producer();
-        m_audioTrackProducers[track] = new Mlt::Producer(*(base->profile()), base->get("resource"));
-        if (m_properties.contains("force_aspect_num") && m_properties.contains("force_aspect_den") && m_properties.contains("frame_size"))
-            m_audioTrackProducers.at(track)->set("force_aspect_ratio", getPixelAspect(m_properties));
-        if (m_properties.contains("force_fps")) m_audioTrackProducers.at(track)->set("force_fps", m_properties.value("force_fps").toDouble());
-        if (m_properties.contains("force_progressive")) m_audioTrackProducers.at(track)->set("force_progressive", m_properties.value("force_progressive").toInt());
-        if (m_properties.contains("force_tff")) m_audioTrackProducers.at(track)->set("force_tff", m_properties.value("force_tff").toInt());
-        if (m_properties.contains("threads")) m_audioTrackProducers.at(track)->set("threads", m_properties.value("threads").toInt());
-        m_audioTrackProducers.at(track)->set("video_index", -1);
-        if (m_properties.contains("audio_index")) m_audioTrackProducers.at(track)->set("audio_index", m_properties.value("audio_index").toInt());
-        m_audioTrackProducers.at(track)->set("id", QString(getId() + '_' + QString::number(track) + "_audio").toUtf8().data());
-        if (m_properties.contains("force_colorspace")) m_audioTrackProducers.at(track)->set("force_colorspace", m_properties.value("force_colorspace").toInt());
-        if (m_properties.contains("full_luma")) m_audioTrackProducers.at(track)->set("set.force_full_luma", m_properties.value("full_luma").toInt());
+        int i;
+        for (i = 0; i < m_audioTrackProducers.count(); i++)
+            if (m_audioTrackProducers.at(i) != NULL) break;
+        Mlt::Producer *base;
+        if (i >= m_audioTrackProducers.count()) {
+            // Could not find a valid producer for that clip
+            locker.unlock();
+            base = getProducer();
+            if (base == NULL) {
+                return NULL;
+            }
+            locker.relock();
+        }
+        else base = m_audioTrackProducers.at(i);
+        m_audioTrackProducers[track] = cloneProducer(base);
+        adjustProducerProperties(m_audioTrackProducers.at(track), QString(getId() + '_' + QString::number(track) + "_audio"), false, true);
     }
     return m_audioTrackProducers.at(track);
 }
 
+
+void DocClipBase::adjustProducerProperties(Mlt::Producer *prod, const QString &id, bool mute, bool blind)
+{
+        if (m_properties.contains("force_aspect_num") && m_properties.contains("force_aspect_den") && m_properties.contains("frame_size"))
+            prod->set("force_aspect_ratio", getPixelAspect(m_properties));
+        if (m_properties.contains("force_fps")) prod->set("force_fps", m_properties.value("force_fps").toDouble());
+        if (m_properties.contains("force_progressive")) prod->set("force_progressive", m_properties.value("force_progressive").toInt());
+        if (m_properties.contains("force_tff")) prod->set("force_tff", m_properties.value("force_tff").toInt());
+        if (m_properties.contains("threads")) prod->set("threads", m_properties.value("threads").toInt());
+        if (mute) prod->set("audio_index", -1);
+        else if (m_properties.contains("audio_index")) prod->set("audio_index", m_properties.value("audio_index").toInt());
+        if (blind) prod->set("video_index", -1);
+        else if (m_properties.contains("video_index")) prod->set("video_index", m_properties.value("video_index").toInt());
+        prod->set("id", id.toUtf8().constData());
+        if (m_properties.contains("force_colorspace")) prod->set("force_colorspace", m_properties.value("force_colorspace").toInt());
+        if (m_properties.contains("full_luma")) prod->set("set.force_full_luma", m_properties.value("full_luma").toInt());
+        if (m_properties.contains("proxy_out")) {
+            // We have a proxy clip, make sure the proxy has same duration as original
+            prod->set("length", m_properties.value("duration").toInt());
+            prod->set("out", m_properties.value("proxy_out").toInt());
+        }
+
+}
+
 Mlt::Producer *DocClipBase::videoProducer()
 {
+    QMutexLocker locker(&m_producerMutex);
     if (m_videoOnlyProducer == NULL) {
         int i;
         for (i = 0; i < m_baseTrackProducers.count(); i++)
             if (m_baseTrackProducers.at(i) != NULL) break;
         if (i >= m_baseTrackProducers.count()) return NULL;
-        m_videoOnlyProducer = new Mlt::Producer(*m_baseTrackProducers.at(i)->profile(), m_baseTrackProducers.at(i)->get("resource"));
-        if (m_properties.contains("force_aspect_num") && m_properties.contains("force_aspect_den") && m_properties.contains("frame_size"))
-            m_videoOnlyProducer->set("force_aspect_ratio", getPixelAspect(m_properties));
-        if (m_properties.contains("force_fps")) m_videoOnlyProducer->set("force_fps", m_properties.value("force_fps").toDouble());
-        if (m_properties.contains("force_progressive")) m_videoOnlyProducer->set("force_progressive", m_properties.value("force_progressive").toInt());
-        if (m_properties.contains("force_tff")) m_videoOnlyProducer->set("force_tff", m_properties.value("force_tff").toInt());
-        if (m_properties.contains("threads")) m_videoOnlyProducer->set("threads", m_properties.value("threads").toInt());
-        m_videoOnlyProducer->set("audio_index", -1);
-        if (m_properties.contains("video_index")) m_videoOnlyProducer->set("video_index", m_properties.value("video_index").toInt());
-        m_videoOnlyProducer->set("id", QString(getId() + "_video").toUtf8().data());
-        if (m_properties.contains("force_colorspace")) m_videoOnlyProducer->set("force_colorspace", m_properties.value("force_colorspace").toInt());
-        if (m_properties.contains("full_luma")) m_videoOnlyProducer->set("set.force_full_luma", m_properties.value("full_luma").toInt());
+        m_videoOnlyProducer = cloneProducer(m_baseTrackProducers.at(i));
+        adjustProducerProperties(m_videoOnlyProducer, QString(getId() + "_video"), true, false);
     }
     return m_videoOnlyProducer;
 }
 
-Mlt::Producer *DocClipBase::producer(int track)
+Mlt::Producer *DocClipBase::getCloneProducer()
 {
-    /*for (int i = 0; i < m_baseTrackProducers.count(); i++) {
-        if (m_baseTrackProducers.at(i)) kDebug() << "// PROD: " << i << ", ID: " << m_baseTrackProducers.at(i)->get("id");
-    }*/
-    if (track == -1 || (m_clipType != AUDIO && m_clipType != AV)) {
-        if (m_baseTrackProducers.count() == 0) return NULL;
+    Mlt::Producer *source = NULL;
+    Mlt::Producer *prod = NULL;
+    if (m_clipType != AUDIO && m_clipType != AV && m_clipType != PLAYLIST) {
+        source = getProducer();
+        if (!source) return NULL;
+    }
+    if (m_clipType == COLOR) {
+        prod = new Mlt::Producer(*(source->profile()), 0, QString("colour:" + QString(source->get("resource"))).toUtf8().constData());
+    } else if (m_clipType == TEXT) {
+        prod = new Mlt::Producer(*(source->profile()), 0, QString("kdenlivetitle:" + QString(source->get("resource"))).toUtf8().constData());
+        if (prod && prod->is_valid() && m_properties.contains("xmldata"))
+            prod->set("xmldata", m_properties.value("xmldata").toUtf8().constData());
+    }
+    if (!prod) {
+        if (!source) {
+            QMutexLocker locker(&m_producerMutex);
+            for (int i = 0; i < m_baseTrackProducers.count(); i++) {
+                if (m_baseTrackProducers.at(i) != NULL) {
+                    source = m_baseTrackProducers.at(i);
+                    break;
+                }
+            }
+            if (!source) return NULL;
+        }
+        prod = cloneProducer(source);
+    }
+    if (prod) {
+        adjustProducerProperties(prod, getId() + "_", false, false);
+        if (!m_properties.contains("proxy_out")) {
+            // Adjust length in case...
+            if (m_properties.contains("duration")) prod->set("length", m_properties.value("duration").toInt());
+            if (m_properties.contains("out"))prod->set("out", m_properties.value("out").toInt());
+        }
+    }
+    return prod;
+}
+
+Mlt::Producer *DocClipBase::getProducer(int track)
+{
+    QMutexLocker locker(&m_producerMutex);
+    if (track == -1 || (m_clipType != AUDIO && m_clipType != AV && m_clipType != PLAYLIST)) {
+        if (m_baseTrackProducers.count() == 0) {
+            return NULL;
+        }
         for (int i = 0; i < m_baseTrackProducers.count(); i++) {
-            if (m_baseTrackProducers.at(i) != NULL)
+            if (m_baseTrackProducers.at(i) != NULL) {
                 return m_baseTrackProducers.at(i);
+            }
         }
         return NULL;
     }
@@ -587,32 +684,48 @@ Mlt::Producer *DocClipBase::producer(int track)
         for (i = 0; i < m_baseTrackProducers.count(); i++)
             if (m_baseTrackProducers.at(i) != NULL) break;
 
-        if (i >= m_baseTrackProducers.count()) return NULL;
-
-        if (KIO::NetAccess::exists(KUrl(m_baseTrackProducers.at(i)->get("resource")), KIO::NetAccess::SourceSide, 0))
-            m_baseTrackProducers[track] = new Mlt::Producer(*m_baseTrackProducers.at(i)->profile(), m_baseTrackProducers.at(i)->get("resource"));
-        else { // special case for placeholder clips
-            m_baseTrackProducers[track] = NULL;
+        if (i >= m_baseTrackProducers.count()) {
+            // Could not find a valid producer for that clip, check in 
             return NULL;
         }
-        if (m_properties.contains("force_aspect_num") && m_properties.contains("force_aspect_den") && m_properties.contains("frame_size"))
-            m_baseTrackProducers[track]->set("force_aspect_ratio", getPixelAspect(m_properties));
-        if (m_properties.contains("force_fps")) m_baseTrackProducers[track]->set("force_fps", m_properties.value("force_fps").toDouble());
-        if (m_properties.contains("force_progressive")) m_baseTrackProducers[track]->set("force_progressive", m_properties.value("force_progressive").toInt());
-        if (m_properties.contains("force_tff")) m_baseTrackProducers[track]->set("force_tff", m_properties.value("force_tff").toInt());
-        if (m_properties.contains("threads")) m_baseTrackProducers[track]->set("threads", m_properties.value("threads").toInt());
-        if (m_properties.contains("video_index")) m_baseTrackProducers[track]->set("video_index", m_properties.value("video_index").toInt());
-        if (m_properties.contains("audio_index")) m_baseTrackProducers[track]->set("audio_index", m_properties.value("audio_index").toInt());
-        m_baseTrackProducers[track]->set("id", QString(getId() + '_' + QString::number(track)).toUtf8().data());
-
-        if (m_properties.contains("force_colorspace")) m_baseTrackProducers[track]->set("force_colorspace", m_properties.value("force_colorspace").toInt());
-        if (m_properties.contains("full_luma")) m_baseTrackProducers[track]->set("set.force_full_luma", m_properties.value("full_luma").toInt());
+        Mlt::Producer *prod = cloneProducer(m_baseTrackProducers.at(i));
+        adjustProducerProperties(prod, QString(getId() + '_' + QString::number(track)), false, false);
+        m_baseTrackProducers[track] = prod;
     }
     return m_baseTrackProducers.at(track);
 }
 
+
+Mlt::Producer *DocClipBase::cloneProducer(Mlt::Producer *source)
+{
+    Mlt::Producer *result = NULL;
+    QString url = QString::fromUtf8(source->get("resource"));
+    if (KIO::NetAccess::exists(KUrl(url), KIO::NetAccess::SourceSide, 0)) {
+        result = new Mlt::Producer(*(source->profile()), url.toUtf8().constData());
+    }
+    if (result == NULL || !result->is_valid()) {
+        // placeholder clip
+        QString txt = "+" + i18n("Missing clip") + ".txt";
+        char *tmp = qstrdup(txt.toUtf8().constData());
+        result = new Mlt::Producer(*source->profile(), tmp);
+        delete[] tmp;
+        if (result == NULL || !result->is_valid())
+            result = new Mlt::Producer(*(source->profile()), "colour:red");
+        else {
+            result->set("bgcolour", "0xff0000ff");
+            result->set("pad", "10");
+        }
+        return result;
+    }
+    /*Mlt::Properties src_props(source->get_properties());
+    Mlt::Properties props(result->get_properties());
+    props.inherit(src_props);*/
+    return result;
+}
+
 void DocClipBase::setProducerProperty(const char *name, int data)
 {
+    QMutexLocker locker(&m_producerMutex);
     for (int i = 0; i < m_baseTrackProducers.count(); i++) {
         if (m_baseTrackProducers.at(i) != NULL)
             m_baseTrackProducers[i]->set(name, data);
@@ -621,6 +734,7 @@ void DocClipBase::setProducerProperty(const char *name, int data)
 
 void DocClipBase::setProducerProperty(const char *name, double data)
 {
+    QMutexLocker locker(&m_producerMutex);
     for (int i = 0; i < m_baseTrackProducers.count(); i++) {
         if (m_baseTrackProducers.at(i) != NULL)
             m_baseTrackProducers[i]->set(name, data);
@@ -629,6 +743,7 @@ void DocClipBase::setProducerProperty(const char *name, double data)
 
 void DocClipBase::setProducerProperty(const char *name, const char *data)
 {
+    QMutexLocker locker(&m_producerMutex);
     for (int i = 0; i < m_baseTrackProducers.count(); i++) {
         if (m_baseTrackProducers.at(i) != NULL)
             m_baseTrackProducers[i]->set(name, data);
@@ -637,6 +752,7 @@ void DocClipBase::setProducerProperty(const char *name, const char *data)
 
 void DocClipBase::resetProducerProperty(const char *name)
 {
+    QMutexLocker locker(&m_producerMutex);
     for (int i = 0; i < m_baseTrackProducers.count(); i++) {
         if (m_baseTrackProducers.at(i) != NULL)
             m_baseTrackProducers[i]->set(name, (const char*) NULL);
@@ -658,10 +774,6 @@ void DocClipBase::slotRefreshProducer()
 {
     if (m_baseTrackProducers.count() == 0) return;
     if (m_clipType == SLIDESHOW) {
-        /*Mlt::Producer producer(*(m_clipProducer->profile()), getProperty("resource").toUtf8().data());
-        delete m_clipProducer;
-        m_clipProducer = new Mlt::Producer(producer.get_producer());
-        if (!getProperty("out").isEmpty()) m_clipProducer->set_in_and_out(getProperty("in").toInt(), getProperty("out").toInt());*/
         setProducerProperty("ttl", getProperty("ttl").toInt());
         //m_clipProducer->set("id", getProperty("id"));
         if (!getProperty("animation").isEmpty()) {
@@ -793,11 +905,23 @@ void DocClipBase::setProperties(QMap <QString, QString> properties)
     bool refreshProducer = false;
     QStringList keys;
     keys << "luma_duration" << "luma_file" << "fade" << "ttl" << "softness" << "crop" << "animation";
+    QString oldProxy = m_properties.value("proxy");
     while (i.hasNext()) {
         i.next();
         setProperty(i.key(), i.value());
         if (m_clipType == SLIDESHOW && keys.contains(i.key())) refreshProducer = true;
     }
+    if (properties.contains("proxy")) {
+        QString value = properties.value("proxy");
+        // If value is "-", that means user manually disabled proxy on this clip
+        if (value.isEmpty() || value == "-") {
+            // reset proxy
+            emit abortProxy(m_id, oldProxy);
+        }
+        else {
+            emit createProxy(m_id);
+        }
+    }
     if (refreshProducer) slotRefreshProducer();
 }
 
@@ -824,7 +948,7 @@ void DocClipBase::clearProperty(const QString &key)
     m_properties.remove(key);
 }
 
-void DocClipBase::getFileHash(const QString url)
+void DocClipBase::getFileHash(const QString &url)
 {
     if (m_clipType == SLIDESHOW) return;
     QFile file(url);
@@ -864,7 +988,7 @@ QString DocClipBase::getClipHash() const
     else if (m_clipType == TEXT) hash = QCryptographicHash::hash(QString("title" + getId() + m_properties.value("xmldata")).toUtf8().data(), QCryptographicHash::Md5).toHex();
     else {
         if (m_properties.contains("file_hash")) hash = m_properties.value("file_hash");
-        else hash = getHash(fileURL().path());
+        if (hash.isEmpty()) hash = getHash(fileURL().path());
         
     }
     return hash;
@@ -970,16 +1094,6 @@ void DocClipBase::setProperty(const QString &key, const QString &value)
             resetProducerProperty("set.force_full_luma");
         } else setProducerProperty("set.force_full_luma", value.toInt());
     }
-    else if (key == "proxy") {
-        // If value is "-", that means user manually disabled proxy on this clip
-        if (value.isEmpty() || value == "-") {
-            // reset proxy
-            emit abortProxy(m_id);
-        }
-        else {
-            emit createProxy(m_id);
-        }
-    }
 }
 
 QMap <QString, QString> DocClipBase::properties() const
@@ -1095,4 +1209,18 @@ bool DocClipBase::hasAudioCodec(const QString &codec) const
 }
 
 
+void DocClipBase::slotExtractImage(QList <int> frames)
+{
+    if (m_thumbProd == NULL) return;
+    m_thumbProd->extractImage(frames);
+}
+
+QPixmap DocClipBase::extractImage(int frame, int width, int height)
+{
+    if (m_thumbProd == NULL) return QPixmap(width, height);
+    QMutexLocker locker(&m_producerMutex);
+    QPixmap p = m_thumbProd->extractImage(frame, width, height);
+    return p;
+}
+
 
