@@ -76,13 +76,12 @@ Q_OBJECT public:
     bool isTransparent() const;
 
     /** Returns any property of this clip. */
-    const QString getProperty(const QString prop) const;
+    const QString getProperty(const QString &prop) const;
     void setProperty(const QString &key, const QString &value);
     void clearProperty(const QString &key);
 
     /** Returns the internal unique id of the clip. */
     const QString &getId() const;
-    void setId(const QString &newId);
 
     //KThumb *thumbCreator;
     bool audioThumbCreated() const;
@@ -117,9 +116,11 @@ Q_OBJECT public:
     }
 
     /** Sets producers for the current clip (one for each track due to a limitation in MLT's track mixing */
-    void setProducer(Mlt::Producer *producer, bool reset = false);
+    void setProducer(Mlt::Producer *producer, bool reset = false, bool readPropertiesFromProducer = false);
     /** Retrieve a producer for a track */
-    Mlt::Producer *producer(int track = -1);
+    Mlt::Producer *getProducer(int track = -1);
+    /** Get a copy of the producer, for use in the clip monitor */
+    Mlt::Producer *getCloneProducer();
     /** Retrieve the producer that shows only video */
     Mlt::Producer *videoProducer();
     /** Retrieve the producer that shows only audio */
@@ -181,8 +182,7 @@ Q_OBJECT public:
     const char *producerProperty(const char *name) const;
     void setProducerProperty(const char *name, const char *data);
     void resetProducerProperty(const char *name);
-    void clearProducers();
-    void deleteProducers(bool clearThumbCreator = true);
+    void deleteProducers();
 
     /** Set default play zone for clip monitor */
     void setZone(QPoint zone);
@@ -204,6 +204,10 @@ Q_OBJECT public:
     bool hasAudioCodec(const QString &codec) const;
     bool checkHash() const;
     void setPlaceHolder(bool place);
+    QPixmap extractImage(int frame, int width, int height);
+    void clearThumbProducer();
+    void cleanupProducers();
+    bool isClean() const;
 
 private:   // Private attributes
 
@@ -212,6 +216,7 @@ private:   // Private attributes
     uint m_refcount;
     QList <Mlt::Producer *> m_baseTrackProducers;
     QList <Mlt::Producer *> m_audioTrackProducers;
+    QList <Mlt::Producer *> m_toDeleteProducers;
     Mlt::Producer *m_videoOnlyProducer;
     CLIPTYPE m_clipType;
 
@@ -239,16 +244,25 @@ private:   // Private attributes
     QMap <QString, QString> m_properties;
     /** Holds clip metadata like author, copyright,... */
     QMap <QString, QString> m_metadata;
+    
+    /** Try to make sure we don't delete a producer while using it */
+    QMutex m_producerMutex;
+    QMutex m_replaceMutex;
 
     /** Create connections for audio thumbnails */
     void slotCreateAudioTimer();
     void slotRefreshProducer();
     void setProducerProperty(const char *name, int data);
     void setProducerProperty(const char *name, double data);
-    void getFileHash(const QString url);
+    void getFileHash(const QString &url);
+    /** @brief When duplicating a producer, make sure all manually set properties are passed to it. */
+    void adjustProducerProperties(Mlt::Producer *prod, const QString &id, bool mute, bool blind);
+    /** @brief Create another instance of a producer. */
+    Mlt::Producer *cloneProducer(Mlt::Producer *source);
 
+   
 public slots:
-    void updateAudioThumbnail(QMap<int, QMap<int, QByteArray> > data);
+    void updateAudioThumbnail(const audioByteArray& data);
     bool slotGetAudioThumbs();
     QList < CommentedTime > commentedSnapMarkers() const;
     GenTime findNextSnapMarker(const GenTime & currTime);
@@ -265,14 +279,14 @@ public slots:
     void setMetadata(QMap <QString, QString> properties);
     QMap <QString, QString> properties() const;
     QMap <QString, QString> metadata() const;
-
+    void slotExtractImage(QList <int> frames);
 
 signals:
     void gotAudioData();
     /** @brief Generate a proxy clip (lower resolution copy) named like the clip's hash. */
-    void createProxy(const QString id);
+    void createProxy(const QString &id);
     /** @brief Abort creation of the proxy clip (lower resolution copy). */
-    void abortProxy(const QString id);
+    void abortProxy(const QString &id, const QString &proxyPath);
 };
 
 #endif
