@@ -48,10 +48,14 @@ const int idRole = Qt::UserRole + 2;
 const int statusRole = Qt::UserRole + 3;
 const int typeRole = Qt::UserRole + 4;
 const int typeOriginalResource = Qt::UserRole + 5;
+const int resetDurationRole = Qt::UserRole + 6;
 
 const int CLIPMISSING = 0;
 const int CLIPOK = 1;
 const int CLIPPLACEHOLDER = 2;
+const int CLIPWRONGDURATION = 3;
+const int PROXYMISSING = 4;
+
 const int LUMAMISSING = 10;
 const int LUMAOK = 11;
 const int LUMAPLACEHOLDER = 12;
@@ -65,30 +69,77 @@ DocumentChecker::DocumentChecker(QDomNodeList infoproducers, QDomDocument doc):
 }
 
 
-bool DocumentChecker::hasMissingClips()
+bool DocumentChecker::hasErrorInClips()
 {
     int clipType;
     QDomElement e;
-    QString id;
     QString resource;
-    QList <QDomElement> missingClips;
-    for (int i = 0; i < m_info.count(); i++) {
+    int max;
+    QDomNodeList documentProducers = m_doc.elementsByTagName("producer");
+    QList <QDomElement> wrongDurationClips;
+    QList <QDomElement> missingProxies;
+    m_safeImages.clear();
+    m_safeFonts.clear();
+    max = m_info.count();
+    for (int i = 0; i < max; i++) {
         e = m_info.item(i).toElement();
         clipType = e.attribute("type").toInt();
         if (clipType == COLOR) continue;
+        if (clipType != TEXT && clipType != IMAGE && clipType != SLIDESHOW) {
+            QString id = e.attribute("id");
+            int duration = e.attribute("duration").toInt();
+            int mltDuration = -1;
+            QDomElement mltProd;
+            QString prodId;
+            // Check that the duration is in sync between Kdenlive's info and MLT's playlist
+            int prodsCount = documentProducers.count();
+            for (int j = 0; j < prodsCount; j++) {
+                mltProd = documentProducers.at(j).toElement();
+                prodId = mltProd.attribute("id");
+                // Don't check slowmotion clips for now... (TODO?)
+                if (prodId.startsWith("slowmotion")) continue;
+                if (prodId.contains("_")) prodId = prodId.section("_", 0, 0);
+                if (prodId != id) continue;
+                if (mltDuration > 0 ) {
+                    // We have several MLT producers for the same clip (probably track producers)
+                    int newLength = EffectsList::property(mltProd, "length").toInt();
+                    if (newLength != mltDuration) {
+                        // we have a different duration for the same clip, that is not safe
+                        e.setAttribute("_resetDuration", 1);
+                    }
+                }
+                mltDuration = EffectsList::property(mltProd, "length").toInt();
+                if (mltDuration != duration) {
+                    // Duration mismatch
+                    e.setAttribute("_mismatch", mltDuration);
+                    if (mltDuration == 15000) {
+                        // a length of 15000 might indicate a wrong clip length since it is a default length
+                        e.setAttribute("_resetDuration", 1);
+                    }
+                    if (!wrongDurationClips.contains(e)) wrongDurationClips.append(e);
+                }
+            }
+        }
+        
         if (clipType == TEXT) {
             //TODO: Check is clip template is missing (xmltemplate) or hash changed
             QStringList images = TitleWidget::extractImageList(e.attribute("xmldata"));
             QStringList fonts = TitleWidget::extractFontList(e.attribute("xmldata"));
-            checkMissingImages(missingClips, images, fonts, e.attribute("id"), e.attribute("name"));
+            checkMissingImagesAndFonts(images, fonts, e.attribute("id"), e.attribute("name"));
             continue;
         }
-        id = e.attribute("id");
         resource = e.attribute("resource");
+        if (e.hasAttribute("proxy")) {
+            QString proxyresource = e.attribute("proxy");
+            if (!proxyresource.isEmpty() && proxyresource != "-" && !KIO::NetAccess::exists(KUrl(proxyresource), KIO::NetAccess::SourceSide, 0)) {
+                // Missing clip found
+                missingProxies.append(e);
+            }
+        }
         if (clipType == SLIDESHOW) resource = KUrl(resource).directory();
         if (!KIO::NetAccess::exists(KUrl(resource), KIO::NetAccess::SourceSide, 0)) {
             // Missing clip found
-            missingClips.append(e);
+            m_missingClips.append(e);
         } else {
             // Check if the clip has changed
             if (clipType != SLIDESHOW && e.hasAttribute("file_hash")) {
@@ -98,21 +149,31 @@ bool DocumentChecker::hasMissingClips()
         }
     }
 
+    // Get list of used Luma files
     QStringList missingLumas;
+    QStringList filesToCheck;
+    QString filePath;
     QString root = m_doc.documentElement().attribute("root");
     if (!root.isEmpty()) root = KUrl(root).path(KUrl::AddTrailingSlash);
     QDomNodeList trans = m_doc.elementsByTagName("transition");
-    for (int i = 0; i < trans.count(); i++) {
+    max = trans.count();
+    for (int i = 0; i < max; i++) {
         QString luma = getProperty(trans.at(i).toElement(), "luma");
-        if (!luma.isEmpty()) {
-            if (!luma.startsWith('/')) luma.prepend(root);
-            if (!QFile::exists(luma) && !missingLumas.contains(luma)) {
-                missingLumas.append(luma);
-            }
+        if (!luma.isEmpty() && !filesToCheck.contains(luma))
+            filesToCheck.append(luma);
+    }
+    // Check existence of luma files
+    foreach (const QString lumafile, filesToCheck) {
+        filePath = lumafile;
+        if (!filePath.startsWith('/')) filePath.prepend(root);
+        if (!QFile::exists(filePath)) {
+            missingLumas.append(lumafile);
         }
     }
+    
+    
 
-    if (missingClips.isEmpty() && missingLumas.isEmpty())
+    if (m_missingClips.isEmpty() && missingLumas.isEmpty() && wrongDurationClips.isEmpty() && missingProxies.isEmpty())
         return false;
 
     m_dialog = new QDialog();
@@ -127,8 +188,9 @@ bool DocumentChecker::hasMissingClips()
     }
 
     m_ui.buttonBox->button(QDialogButtonBox::Ok)->setEnabled(false);
-    for (int i = 0; i < missingClips.count(); i++) {
-        e = missingClips.at(i).toElement();
+    max = m_missingClips.count();
+    for (int i = 0; i < max; i++) {
+        e = m_missingClips.at(i).toElement();
         QString clipType;
         int t = e.attribute("type").toInt();
         switch (t) {
@@ -182,10 +244,127 @@ bool DocumentChecker::hasMissingClips()
         }
         item->setData(0, typeRole, t);
         item->setData(0, idRole, e.attribute("id"));
+        item->setToolTip(0, i18n("Missing item"));
     }
+
+    if (m_missingClips.count() > 0) {
+        if (wrongDurationClips.count() > 0) {
+            m_ui.infoLabel->setText(i18n("The project file contains missing clips or files and clip duration mismatch"));
+        }
+        else {
+            m_ui.infoLabel->setText(i18n("The project file contains missing clips or files"));
+        }
+    }
+    else if (wrongDurationClips.count() > 0) {
+        m_ui.infoLabel->setText(i18n("The project file contains clips with duration mismatch"));
+    }
+    if (missingProxies.count() > 0) {
+        if (!m_ui.infoLabel->text().isEmpty()) m_ui.infoLabel->setText(m_ui.infoLabel->text() + ". ");
+        m_ui.infoLabel->setText(m_ui.infoLabel->text() + i18n("Missing proxies will be recreated after opening."));
+    }
+
+    m_ui.removeSelected->setEnabled(!m_missingClips.isEmpty());
+    m_ui.recursiveSearch->setEnabled(!m_missingClips.isEmpty() || !missingLumas.isEmpty());
+    m_ui.usePlaceholders->setEnabled(!m_missingClips.isEmpty());
+    m_ui.fixDuration->setEnabled(!wrongDurationClips.isEmpty());
+
+    max = wrongDurationClips.count();
+    for (int i = 0; i < max; i++) {
+        e = wrongDurationClips.at(i).toElement();
+        QString clipType;
+        int t = e.attribute("type").toInt();
+        switch (t) {
+        case AV:
+            clipType = i18n("Video clip");
+            break;
+        case VIDEO:
+            clipType = i18n("Mute video clip");
+            break;
+        case AUDIO:
+            clipType = i18n("Audio clip");
+            break;
+        case PLAYLIST:
+            clipType = i18n("Playlist clip");
+            break;
+        case IMAGE:
+            clipType = i18n("Image clip");
+            break;
+        case SLIDESHOW:
+            clipType = i18n("Slideshow clip");
+            break;
+        default:
+            clipType = i18n("Video clip");
+        }
+        QTreeWidgetItem *item = new QTreeWidgetItem(m_ui.treeWidget, QStringList() << clipType);
+        item->setIcon(0, KIcon("timeadjust"));
+        item->setText(1, e.attribute("resource"));
+        item->setData(0, hashRole, e.attribute("file_hash"));
+        item->setData(0, sizeRole, e.attribute("_mismatch"));
+        e.removeAttribute("_mismatch");
+        item->setData(0, resetDurationRole, (int) e.hasAttribute("_resetDuration"));
+        e.removeAttribute("_resetDuration");
+        item->setData(0, statusRole, CLIPWRONGDURATION);
+        item->setData(0, typeRole, t);
+        item->setData(0, idRole, e.attribute("id"));
+        item->setToolTip(0, i18n("Duration mismatch"));
+    }
+
+    if (missingProxies.count() > 0) {
+        QTreeWidgetItem *item = new QTreeWidgetItem(m_ui.treeWidget, QStringList() << i18n("Proxy clip"));
+        item->setIcon(0, KIcon("dialog-warning"));
+        item->setText(1, i18n("%1 missing proxy clips, will be recreated on project opening", missingProxies.count()));
+        item->setData(0, hashRole, e.attribute("file_hash"));
+        item->setData(0, statusRole, PROXYMISSING);
+        item->setToolTip(0, i18n("Missing proxy"));
+    }
+
+    max = missingProxies.count();
+    for (int i = 0; i < max; i++) {
+        e = missingProxies.at(i).toElement();
+        QString clipType;
+        QString realPath = e.attribute("resource");
+        QString id = e.attribute("id");
+        // Replace proxy url with real clip in MLT producers
+        QDomNodeList properties;
+        QDomElement mltProd;
+        QDomElement property;
+        int prodsCount = documentProducers.count();
+        for (int j = 0; j < prodsCount; j++) {
+            mltProd = documentProducers.at(j).toElement();
+            QString prodId = mltProd.attribute("id");
+            bool slowmotion = false;
+            if (prodId.startsWith("slowmotion")) {
+                slowmotion = true;
+                prodId = prodId.section(':', 1, 1);
+            }
+            if (prodId.contains('_')) prodId = prodId.section('_', 0, 0);
+            if (prodId == id) {
+                // Hit, we must replace url
+                properties = mltProd.childNodes();
+                for (int k = 0; k < properties.count(); ++k) {
+                    property = properties.item(k).toElement();
+                    if (property.attribute("name") == "resource") {
+                        QString resource = property.firstChild().nodeValue();                    
+                        QString suffix;
+                        if (slowmotion) suffix = "?" + resource.section('?', -1);
+                        property.firstChild().setNodeValue(realPath + suffix);
+                        break;
+                    }
+                }
+            }
+        }
+    }
+    
+    if (missingProxies.count() > 0) {
+        // original doc was modified
+        QDomElement infoXml = m_doc.elementsByTagName("kdenlivedoc").at(0).toElement();
+        infoXml.setAttribute("modified", "1");
+    }
+    
     connect(m_ui.recursiveSearch, SIGNAL(pressed()), this, SLOT(slotSearchClips()));
     connect(m_ui.usePlaceholders, SIGNAL(pressed()), this, SLOT(slotPlaceholders()));
     connect(m_ui.removeSelected, SIGNAL(pressed()), this, SLOT(slotDeleteSelected()));
+    connect(m_ui.fixDuration, SIGNAL(pressed()), this, SLOT(slotFixDuration()));
     connect(m_ui.treeWidget, SIGNAL(itemDoubleClicked(QTreeWidgetItem *, int)), this, SLOT(slotEditItem(QTreeWidgetItem *, int)));
     connect(m_ui.treeWidget, SIGNAL(itemSelectionChanged()), this, SLOT(slotCheckButtons()));
     //adjustSize();
@@ -230,12 +409,15 @@ void DocumentChecker::slotSearchClips()
     QString newpath = KFileDialog::getExistingDirectory(KUrl("kfiledialog:///clipfolder"), kapp->activeWindow(), i18n("Clips folder"));
     if (newpath.isEmpty()) return;
     int ix = 0;
+    bool fixed = false;
     m_ui.recursiveSearch->setEnabled(false);
     QTreeWidgetItem *child = m_ui.treeWidget->topLevelItem(ix);
+    QDir searchDir(newpath);
     while (child) {
         if (child->data(0, statusRole).toInt() == CLIPMISSING) {
-            QString clipPath = searchFileRecursively(QDir(newpath), child->data(0, sizeRole).toString(), child->data(0, hashRole).toString());
+            QString clipPath = searchFileRecursively(searchDir, child->data(0, sizeRole).toString(), child->data(0, hashRole).toString());
             if (!clipPath.isEmpty()) {
+                fixed = true;
                 child->setText(1, clipPath);
                 child->setIcon(0, KIcon("dialog-ok"));
                 child->setData(0, statusRole, CLIPOK);
@@ -243,20 +425,38 @@ void DocumentChecker::slotSearchClips()
         } else if (child->data(0, statusRole).toInt() == LUMAMISSING) {
             QString fileName = searchLuma(child->data(0, idRole).toString());
             if (!fileName.isEmpty()) {
+                fixed = true;
                 child->setText(1, fileName);
                 child->setIcon(0, KIcon("dialog-ok"));
                 child->setData(0, statusRole, LUMAOK);
             }
         }
+        else if (child->data(0, typeRole).toInt() == TITLE_IMAGE_ELEMENT && child->data(0, statusRole).toInt() == CLIPPLACEHOLDER) {
+            // Search missing title images
+            QString missingFileName = KUrl(child->text(1)).fileName();
+            QString newPath = searchPathRecursively(searchDir, missingFileName);
+            if (!newPath.isEmpty()) {
+                // File found
+                fixed = true;
+                child->setText(1, newPath);
+                child->setIcon(0, KIcon("dialog-ok"));
+                child->setData(0, statusRole, CLIPOK);
+            }
+        }
         ix++;
         child = m_ui.treeWidget->topLevelItem(ix);
     }
     m_ui.recursiveSearch->setEnabled(true);
+    if (fixed) {
+        // original doc was modified
+        QDomElement infoXml = m_doc.elementsByTagName("kdenlivedoc").at(0).toElement();
+        infoXml.setAttribute("modified", "1");
+    }
     checkStatus();
 }
 
 
-QString DocumentChecker::searchLuma(QString file) const
+QString DocumentChecker::searchLuma(const QString &file) const
 {
     KUrl searchPath(KdenliveSettings::mltpath());
     if (file.contains("PAL"))
@@ -264,11 +464,36 @@ QString DocumentChecker::searchLuma(QString file) const
     else
         searchPath.cd("../lumas/NTSC");
     QString result = searchPath.path(KUrl::AddTrailingSlash) + KUrl(file).fileName();
+    if (QFile::exists(result))
+        return result;
+    // try to find luma in application path
+    searchPath.clear();
+    searchPath = KUrl(QCoreApplication::applicationDirPath());
+    searchPath.cd("../share/apps/kdenlive/lumas");
+    result = searchPath.path(KUrl::AddTrailingSlash) + KUrl(file).fileName();
     if (QFile::exists(result))
         return result;
     return QString();
 }
 
+QString DocumentChecker::searchPathRecursively(const QDir &dir, const QString &fileName) const
+{
+    QString foundFileName;
+    QStringList filters;
+    filters << fileName;
+    QDir searchDir(dir);
+    searchDir.setNameFilters(filters);
+    QStringList filesAndDirs = searchDir.entryList(QDir::Files | QDir::Readable);
+    if (!filesAndDirs.isEmpty()) return searchDir.absoluteFilePath(filesAndDirs.at(0));
+    searchDir.setNameFilters(QStringList());
+    filesAndDirs = searchDir.entryList(QDir::Dirs | QDir::Readable | QDir::Executable | QDir::NoDotAndDotDot);
+    for (int i = 0; i < filesAndDirs.size() && foundFileName.isEmpty(); i++) {
+        foundFileName = searchPathRecursively(searchDir.absoluteFilePath(filesAndDirs.at(i)), fileName);
+        if (!foundFileName.isEmpty())
+            break;
+    }
+    return foundFileName;
+}
 
 QString DocumentChecker::searchFileRecursively(const QDir &dir, const QString &matchSize, const QString &matchHash) const
 {
@@ -422,6 +647,7 @@ void DocumentChecker::acceptDialog()
         } else if (child->data(0, statusRole).toInt() == LUMAOK) {
             for (int i = 0; i < trans.count(); i++) {
                 QString luma = getProperty(trans.at(i).toElement(), "luma");
+                
                 kDebug() << "luma: " << luma;
                 if (!luma.isEmpty() && luma == child->data(0, idRole).toString()) {
                     setProperty(trans.at(i).toElement(), "luma", child->text(1));
@@ -460,6 +686,52 @@ void DocumentChecker::slotPlaceholders()
     checkStatus();
 }
 
+void DocumentChecker::slotFixDuration()
+{
+    int ix = 0;
+    QTreeWidgetItem *child = m_ui.treeWidget->topLevelItem(ix);
+    QDomNodeList documentProducers = m_doc.elementsByTagName("producer");
+    while (child) {
+        if (child->data(0, statusRole).toInt() == CLIPWRONGDURATION) {
+            QString id = child->data(0, idRole).toString();
+            bool resetDuration = child->data(0, resetDurationRole).toInt();
+
+            for (int i = 0; i < m_info.count(); i++) {
+                QDomElement e = m_info.at(i).toElement();
+                if (e.attribute("id") == id) {
+                    if (m_missingClips.contains(e)) {
+                        // we cannot fix duration of missing clips
+                        resetDuration = false;
+                    }
+                    else {
+                        if (resetDuration) e.removeAttribute("duration");
+                        else e.setAttribute("duration", child->data(0, sizeRole).toString());
+                        child->setData(0, statusRole, CLIPOK);
+                        child->setIcon(0, KIcon("dialog-ok"));
+                    }
+                    break;
+                }
+            }
+            if (resetDuration) {
+                // something is wrong in clip durations, so remove them so mlt fetches them again
+                for (int j = 0; j < documentProducers.count(); j++) {
+                    QDomElement mltProd = documentProducers.at(j).toElement();
+                    QString prodId = mltProd.attribute("id");
+                    if (prodId == id || prodId.startsWith(id + "_")) {
+                        EffectsList::removeProperty(mltProd, "length");
+                    }
+                }
+            }
+        }
+        ix++;
+        child = m_ui.treeWidget->topLevelItem(ix);
+    }
+    QDomElement infoXml = m_doc.elementsByTagName("kdenlivedoc").at(0).toElement();
+    infoXml.setAttribute("modified", "1");
+    m_ui.fixDuration->setEnabled(false);
+    checkStatus();
+}
+
 
 void DocumentChecker::checkStatus()
 {
@@ -467,7 +739,8 @@ void DocumentChecker::checkStatus()
     int ix = 0;
     QTreeWidgetItem *child = m_ui.treeWidget->topLevelItem(ix);
     while (child) {
-        if (child->data(0, statusRole).toInt() == CLIPMISSING || child->data(0, statusRole).toInt() == LUMAMISSING) {
+        int status = child->data(0, statusRole).toInt();
+        if (status == CLIPMISSING || status == LUMAMISSING || status == CLIPWRONGDURATION) {
             status = false;
             break;
         }
@@ -483,23 +756,40 @@ void DocumentChecker::slotDeleteSelected()
     if (KMessageBox::warningContinueCancel(m_dialog, i18np("This will remove the selected clip from this project", "This will remove the selected clips from this project", m_ui.treeWidget->selectedItems().count()), i18n("Remove clips")) == KMessageBox::Cancel)
         return;
     QStringList deletedIds;
+    QStringList deletedLumas;
     QDomNodeList playlists = m_doc.elementsByTagName("playlist");
 
     foreach(QTreeWidgetItem *child, m_ui.treeWidget->selectedItems()) {
-        if (child->data(0, statusRole).toInt() < 10) {
+        int id = child->data(0, statusRole).toInt();
+        if (id == CLIPMISSING) {
             deletedIds.append(child->data(0, idRole).toString());
             delete child;
         }
+        else if (id == LUMAMISSING) {
+            deletedLumas.append(child->data(0, idRole).toString());
+            delete child;
+        }
+    }
+
+    if (!deletedLumas.isEmpty()) {
+        QDomElement e;
+        QDomNodeList transitions = m_doc.elementsByTagName("transition");
+        foreach (QString lumaPath, deletedLumas) {
+            for (int i = 0; i < transitions.count(); i++) {
+                e = transitions.item(i).toElement();
+                QString resource = EffectsList::property(e, "luma");
+                if (resource == lumaPath) EffectsList::removeProperty(e, "luma");
+            }
+        }
     }
-    kDebug() << "// Clips to delete: " << deletedIds;
 
     if (!deletedIds.isEmpty()) {
         QDomElement e;
         QDomNodeList producers = m_doc.elementsByTagName("producer");
         QDomNodeList infoproducers = m_doc.elementsByTagName("kdenlive_producer");
 
-        QDomElement mlt = m_doc.firstChildElement("mlt");
-        QDomElement kdenlivedoc = mlt.firstChildElement("kdenlivedoc");
+        QDomNode mlt = m_doc.elementsByTagName("mlt").at(0);
+        QDomNode kdenlivedoc = m_doc.elementsByTagName("kdenlivedoc").at(0);
 
         for (int i = 0, j = 0; i < infoproducers.count() && j < deletedIds.count(); i++) {
             e = infoproducers.item(i).toElement();
@@ -536,35 +826,40 @@ void DocumentChecker::slotDeleteSelected()
                 }
             }
         }
+        QDomElement infoXml = m_doc.elementsByTagName("kdenlivedoc").at(0).toElement();
+        infoXml.setAttribute("modified", "1");
         checkStatus();
     }
 }
 
-void DocumentChecker::checkMissingImages(QList <QDomElement>&missingClips, QStringList images, QStringList fonts, QString id, QString baseClip)
+void DocumentChecker::checkMissingImagesAndFonts(QStringList images, QStringList fonts, const QString &id, const QString &baseClip)
 {
     QDomDocument doc;
     foreach(const QString &img, images) {
+        if (m_safeImages.contains(img)) continue;
         if (!KIO::NetAccess::exists(KUrl(img), KIO::NetAccess::SourceSide, 0)) {
             QDomElement e = doc.createElement("missingclip");
             e.setAttribute("type", TITLE_IMAGE_ELEMENT);
             e.setAttribute("resource", img);
             e.setAttribute("id", id);
             e.setAttribute("name", baseClip);
-            missingClips.append(e);
+            m_missingClips.append(e);
         }
+        else m_safeImages.append(img);
     }
-    kDebug() << "/ / / CHK FONTS: " << fonts;
     foreach(const QString &fontelement, fonts) {
+        if (m_safeFonts.contains(fontelement)) continue;
         QFont f(fontelement);
-        kDebug() << "/ / / CHK FONTS: " << fontelement << " = " << QFontInfo(f).family();
+        //kDebug() << "/ / / CHK FONTS: " << fontelement << " = " << QFontInfo(f).family();
         if (fontelement != QFontInfo(f).family()) {
             QDomElement e = doc.createElement("missingclip");
             e.setAttribute("type", TITLE_FONT_ELEMENT);
             e.setAttribute("resource", fontelement);
             e.setAttribute("id", id);
             e.setAttribute("name", baseClip);
-            missingClips.append(e);
+            m_missingClips.append(e);
         }
+        else m_safeFonts.append(fontelement);
     }
 }
 
@@ -574,7 +869,8 @@ void DocumentChecker::slotCheckButtons()
     if (m_ui.treeWidget->currentItem()) {
         QTreeWidgetItem *item = m_ui.treeWidget->currentItem();
         int t = item->data(0, typeRole).toInt();
-        if (t == TITLE_FONT_ELEMENT || t == TITLE_IMAGE_ELEMENT) {
+        int s = item->data(0, statusRole).toInt();
+        if (t == TITLE_FONT_ELEMENT || t == TITLE_IMAGE_ELEMENT || s == PROXYMISSING) {
             m_ui.removeSelected->setEnabled(false);
         } else m_ui.removeSelected->setEnabled(true);
     }
