@@ -20,14 +20,26 @@
 
 #include "documentvalidator.h"
 #include "definitions.h"
+#include "initeffects.h"
+#include "mainwindow.h"
 
 #include <KDebug>
 #include <KMessageBox>
 #include <KApplication>
 #include <KLocale>
+#include <KUrl>
+#include <KStandardDirs>
 
 #include <QFile>
 #include <QColor>
+#include <QString>
+#include <QDir>
+#include <QScriptEngine>
+
+#include <mlt++/Mlt.h>
+
+#include "locale.h"
+
 
 DocumentValidator::DocumentValidator(QDomDocument doc):
         m_doc(doc),
@@ -45,8 +57,33 @@ bool DocumentValidator::validate(const double currentVersion)
     // Check if we're validating a Kdenlive project
     if (kdenliveDoc.isNull())
         return false;
+
+    // Previous MLT / Kdenlive versions used C locale by default
+    QLocale documentLocale = QLocale::c();
+    
+    if (mlt.hasAttribute("LC_NUMERIC")) {
+        // Set locale for the document
+        // WARNING: what should be done in case the locale does not exist on the system?
+        setlocale(LC_NUMERIC, mlt.attribute("LC_NUMERIC").toUtf8().constData());
+        documentLocale = QLocale(mlt.attribute("LC_NUMERIC"));
+    }
+    
+    documentLocale.setNumberOptions(QLocale::OmitGroupSeparator);
+    if (documentLocale.decimalPoint() != QLocale().decimalPoint()) {
+        // If loading an older MLT file without LC_NUMERIC, set locale to C which was previously the default
+        if (!mlt.hasAttribute("LC_NUMERIC")) setlocale(LC_NUMERIC, "C");
+
+        QLocale::setDefault(documentLocale);
+        // locale conversion might need to be redone
+        initEffects::parseEffectFiles();
+    }
+
+    // TODO: remove after string freeze
+    if (0)
+        KMessageBox::sorry(kapp->activeWindow(), i18n("The document you are opening uses a different locale (%1) than your system. You can only open and render it, no editing is supported unless you change your system's locale.", mlt.attribute("LC_NUMERIC")), i18n("Read only project"));
+
     // Upgrade the document to the latest version
-    if (!upgrade(kdenliveDoc.attribute("version").toDouble(), currentVersion))
+    if (!upgrade(documentLocale.toDouble(kdenliveDoc.attribute("version")), currentVersion))
         return false;
 
     /*
@@ -88,7 +125,7 @@ bool DocumentValidator::validate(const double currentVersion)
                 // Looks like one MLT track is missing, remove the extra Kdenlive track if there is one.
                 if (tracksinfo.count() != tracks.count() - 1) {
                     // The Kdenlive tracks are not ok, clear and rebuild them
-                    QDomNode tinfo = kdenliveDoc.elementsByTagName("tracksinfo").at(0);
+                    QDomNode tinfo = kdenliveDoc.firstChildElement("tracksinfo");
                     QDomNode tnode = tinfo.firstChild();
                     while (!tnode.isNull()) {
                         tinfo.removeChild(tnode);
@@ -142,12 +179,15 @@ bool DocumentValidator::validate(const double currentVersion)
                     tracksinfoElm.appendChild(trackinfo);
                 }
             }
-        }
+        }        
 
         // TODO: check the tracks references
         // TODO: check internal mix transitions
+        
     }
 
+    updateEffects();
+
     return true;
 }
 
@@ -811,7 +851,84 @@ bool DocumentValidator::upgrade(double version, const double currentVersion)
             }
         }
     }
+    if (version <= 0.85) {
+        // update the LADSPA effects to use the new ladspa.id format instead of external xml file
+        QDomNodeList effectNodes = m_doc.elementsByTagName("filter");
+        for (int i = 0; i < effectNodes.count(); ++i) {
+            QDomElement effect = effectNodes.at(i).toElement();
+            if (EffectsList::property(effect, "mlt_service") == "ladspa") {
+                // Needs to be converted
+                QStringList info = getInfoFromEffectName(EffectsList::property(effect, "kdenlive_id"));
+                if (info.isEmpty()) continue;
+                // info contains the correct ladspa.id from kdenlive effect name, and a list of parameter's old and new names
+                EffectsList::setProperty(effect, "kdenlive_id", info.at(0));
+                EffectsList::setProperty(effect, "tag", info.at(0));
+                EffectsList::setProperty(effect, "mlt_service", info.at(0));
+                EffectsList::removeProperty(effect, "src");
+                for (int j = 1; j < info.size(); j++) {
+                    QString value = EffectsList::property(effect, info.at(j).section('=', 0, 0));
+                    if (!value.isEmpty()) {
+                        // update parameter name
+                        EffectsList::renameProperty(effect, info.at(j).section('=', 0, 0), info.at(j).section('=', 1, 1));
+                    }
+                }
+            }
+        }
+    }
 
+    if (version <= 0.86) {
+        // Make sure we don't have avformat-novalidate producers, since it caused crashes
+        QDomNodeList producers = m_doc.elementsByTagName("producer");
+        int max = producers.count();
+        for (int i = 0; i < max; i++) {
+            QDomElement prod = producers.at(i).toElement();
+            if (EffectsList::property(prod, "mlt_service") == "avformat-novalidate")
+                EffectsList::setProperty(prod, "mlt_service", "avformat");
+        }
+
+        // There was a mistake in Geometry transitions where the last keyframe was created one frame after the end of transition, so fix it and move last keyframe to real end of transition
+
+        // Get profile info (width / height)
+        int profileWidth;
+        int profileHeight;
+        QDomElement profile = m_doc.firstChildElement("profile");
+        if (profile.isNull()) profile = infoXml.firstChildElement("profileinfo");
+        if (profile.isNull()) {
+            // could not find profile info, set PAL
+            profileWidth = 720;
+            profileHeight = 576;
+        }
+        else {
+            profileWidth = profile.attribute("width").toInt();
+            profileHeight = profile.attribute("height").toInt();
+        }
+        QDomNodeList transitions = m_doc.elementsByTagName("transition");
+        max = transitions.count();
+        int out;
+        for (int i = 0; i < max; i++) {
+            QDomElement trans = transitions.at(i).toElement();
+            out = trans.attribute("out").toInt() - trans.attribute("in").toInt();
+            QString geom = EffectsList::property(trans, "geometry");
+            Mlt::Geometry *g = new Mlt::Geometry(geom.toUtf8().data(), out, profileWidth, profileHeight);
+            Mlt::GeometryItem item;
+            if (g->next_key(&item, out) == 0) {
+                // We have a keyframe just after last frame, try to move it to last frame
+                if (item.frame() == out + 1) {
+                    item.frame(out);
+                    g->insert(item);
+                    g->remove(out + 1);
+                    EffectsList::setProperty(trans, "geometry", g->serialise());
+                }
+            }
+            delete g;
+        }
+    }
+
+    if (version <= 0.87) {
+        if (!m_doc.firstChildElement("mlt").hasAttribute("LC_NUMERIC")) {
+            m_doc.firstChildElement("mlt").setAttribute("LC_NUMERIC", "C");
+        }
+    }
 
     // The document has been converted: mark it as modified
     infoXml.setAttribute("version", currentVersion);
@@ -819,6 +936,84 @@ bool DocumentValidator::upgrade(double version, const double currentVersion)
     return true;
 }
 
+QStringList DocumentValidator::getInfoFromEffectName(const QString oldName)
+{
+    QStringList info;
+    // Returns a list to convert old Kdenlive ladspa effects
+    if (oldName == "pitch_shift") {
+        info << "ladspa.1433";
+        info << "pitch=0";
+    }
+    else if (oldName == "vinyl") {
+        info << "ladspa.1905";
+        info << "year=0";
+        info << "rpm=1";
+        info << "warping=2";
+        info << "crackle=3";
+        info << "wear=4";
+    }
+    else if (oldName == "room_reverb") {
+        info << "ladspa.1216";
+        info << "room=0";
+        info << "delay=1";
+        info << "damp=2";
+    }
+    else if (oldName == "reverb") {
+        info << "ladspa.1423";
+        info << "room=0";
+        info << "damp=1";
+    }
+    else if (oldName == "rate_scale") {
+        info << "ladspa.1417";
+        info << "rate=0";
+    }
+    else if (oldName == "pitch_scale") {
+        info << "ladspa.1193";
+        info << "coef=0";
+    }
+    else if (oldName == "phaser") {
+        info << "ladspa.1217";
+        info << "rate=0";
+        info << "depth=1";
+        info << "feedback=2";
+        info << "spread=3";
+    }
+    else if (oldName == "limiter") {
+        info << "ladspa.1913";
+        info << "gain=0";
+        info << "limit=1";
+        info << "release=2";
+    }
+    else if (oldName == "equalizer_15") {
+        info << "ladspa.1197";
+        info << "1=0";
+        info << "2=1";
+        info << "3=2";
+        info << "4=3";
+        info << "5=4";
+        info << "6=5";
+        info << "7=6";
+        info << "8=7";
+        info << "9=8";
+        info << "10=9";
+        info << "11=10";
+        info << "12=11";
+        info << "13=12";
+        info << "14=13";
+        info << "15=14";
+    }
+    else if (oldName == "equalizer") {
+        info << "ladspa.1901";
+        info << "logain=0";
+        info << "midgain=1";
+        info << "higain=2";
+    }
+    else if (oldName == "declipper") {
+        info << "ladspa.1195";
+    }
+    return info;
+}
+
 QString DocumentValidator::colorToString(const QColor& c)
 {
     QString ret = "%1,%2,%3,%4";
@@ -836,3 +1031,138 @@ bool DocumentValidator::isModified() const
 {
     return m_modified;
 }
+
+void DocumentValidator::updateEffects()
+{
+    // WARNING: order by findDirs will determine which js file to use (in case multiple scripts for the same filter exist)
+    QMap <QString, KUrl> paths;
+#if QT_VERSION >= 0x040700
+    QMap <QString, QScriptProgram> scripts;
+#else
+    QMap <QString, QString> scripts;
+#endif
+    QStringList directories = KGlobal::dirs()->findDirs("appdata", "effects/update");
+    foreach (const QString &directoryName, directories) {
+        QDir directory(directoryName);
+        QStringList fileList = directory.entryList(QStringList() << "*.js", QDir::Files);
+        foreach (const QString &fileName, fileList) {
+            QString identifier = fileName;
+            // remove extension (".js")
+            identifier.chop(3);
+            paths.insert(identifier, KUrl(directoryName + fileName));
+        }
+    }
+
+    QDomNodeList effects = m_doc.elementsByTagName("filter");
+    int max = effects.count();
+    QStringList safeEffects;
+    for(int i = 0; i < max; ++i) {
+        QDomElement effect = effects.at(i).toElement();
+        QString effectId = EffectsList::property(effect, "kdenlive_id");
+        if (safeEffects.contains(effectId)) {
+            // Do not check the same effect twice if it is at the correct version
+            // (assume we don't have different versions of the same effect in a project file)
+            continue;
+        }
+        QString effectTag = EffectsList::property(effect, "tag");
+        QString effectVersionStr = EffectsList::property(effect, "version");
+        double effectVersion = effectVersionStr.isNull() ? -1 : effectVersionStr.toDouble();
+
+        QDomElement effectDescr = MainWindow::customEffects.getEffectByTag(QString(), effectId);
+        if (effectDescr.isNull()) {
+            effectDescr = MainWindow::videoEffects.getEffectByTag(effectTag, effectId);
+        }
+        if (effectDescr.isNull()) {
+            effectDescr = MainWindow::audioEffects.getEffectByTag(effectTag, effectId);
+        }
+        if (!effectDescr.isNull()) {
+            double serviceVersion = -1;
+            QDomElement serviceVersionElem = effectDescr.firstChildElement("version");
+            if (!serviceVersionElem.isNull()) {
+                serviceVersion = serviceVersionElem.text().toDouble();
+            }
+            if (serviceVersion != effectVersion && paths.contains(effectId)) {
+                if (!scripts.contains(effectId)) {
+                    QFile scriptFile(paths.value(effectId).path());
+                    if (!scriptFile.open(QIODevice::ReadOnly)) {
+                        continue;
+                    }
+#if QT_VERSION >= 0x040700
+                    QScriptProgram scriptProgram(scriptFile.readAll());
+#else
+                    QString scriptProgram = scriptFile.readAll();
+#endif
+                    scriptFile.close();
+                    scripts.insert(effectId, scriptProgram);
+                }
+
+                QScriptEngine scriptEngine;
+                scriptEngine.importExtension("qt.core");
+                scriptEngine.importExtension("qt.xml");
+                scriptEngine.evaluate(scripts.value(effectId));
+                QScriptValue updateRules = scriptEngine.globalObject().property("update");
+                if (!updateRules.isValid())
+                    continue;
+                if (updateRules.isFunction()) {
+                    QDomDocument scriptDoc;
+                    scriptDoc.appendChild(scriptDoc.importNode(effect, true));
+
+                    QString effectString = updateRules.call(QScriptValue(), QScriptValueList()  << serviceVersion << effectVersion << scriptDoc.toString()).toString();
+
+                    if (!effectString.isEmpty() && !scriptEngine.hasUncaughtException()) {
+                        scriptDoc.setContent(effectString);
+                        QDomNode updatedEffect = effect.ownerDocument().importNode(scriptDoc.documentElement(), true);
+                        effect.parentNode().replaceChild(updatedEffect, effect);
+                        m_modified = true;
+                    }
+                } else {
+                    m_modified = updateEffectParameters(effect.childNodes(), &updateRules, serviceVersion, effectVersion);
+                }
+
+                // set version number since MLT won't change it (only initially set it)
+                QDomElement versionElem = effect.firstChildElement("version");
+                if (EffectsList::property(effect, "version").isNull()) {
+                    versionElem = effect.ownerDocument().createTextNode(QLocale().toString(serviceVersion)).toElement();
+                    versionElem.setTagName("property");
+                    versionElem.setAttribute("name", "version");
+                    effect.appendChild(versionElem);
+                } else {
+                    EffectsList::setProperty(effect, "version", QLocale().toString(serviceVersion));
+                }
+            }
+            else safeEffects.append(effectId);
+        }
+    }
+}
+
+bool DocumentValidator::updateEffectParameters(QDomNodeList parameters, const QScriptValue* updateRules, const double serviceVersion, const double effectVersion)
+{
+    bool updated = false;
+    bool isDowngrade = serviceVersion < effectVersion;
+    for (int i = 0; i < parameters.count(); ++i) {
+        QDomElement parameter = parameters.at(i).toElement();
+        QScriptValue rules = updateRules->property(parameter.attribute("name"));
+        if (rules.isValid() && rules.isArray()) {
+            int rulesCount = rules.property("length").toInt32();
+            if (isDowngrade) {
+                // start with the highest version and downgrade step by step
+                for (int j = rulesCount - 1; j >= 0; --j) {
+                    double version = rules.property(j).property(0).toNumber();
+                    if (version <= effectVersion && version > serviceVersion) {
+                        parameter.firstChild().setNodeValue(rules.property(j).property(1).call(QScriptValue(), QScriptValueList() << parameter.text() << isDowngrade).toString());
+                        updated = true;
+                    }
+                }
+            } else {
+                for (int j = 0; j < rulesCount; ++j) {
+                    double version = rules.property(j).property(0).toNumber();
+                    if (version > effectVersion && version <= serviceVersion) {
+                        parameter.firstChild().setNodeValue(rules.property(j).property(1).call(QScriptValue(), QScriptValueList() << parameter.text() << isDowngrade).toString());
+                        updated = true;
+                    }
+                }
+            }
+        }
+    }
+    return updated;
+}
