@@ -26,11 +26,12 @@
 #include <QSpinBox>
 #include <QToolButton>
 
+#include <KDebug>
 #include <KIcon>
 #include <KLocalizedString>
 
 
-DoubleParameterWidget::DoubleParameterWidget(const QString &name, int value, int min, int max, int defaultValue, const QString &comment, int id, const QString suffix, QWidget *parent) :
+DoubleParameterWidget::DoubleParameterWidget(const QString &name, double value, double min, double max, double defaultValue, const QString &comment, int id, const QString suffix, int decimals, QWidget *parent) :
         QWidget(parent),
         m_commentLabel(NULL)
 {
@@ -39,9 +40,7 @@ DoubleParameterWidget::DoubleParameterWidget(const QString &name, int value, int
     layout->setContentsMargins(0, 0, 0, 0);
     layout->setSpacing(0);
     
-    m_dragVal = new DragValue(name, defaultValue, 0, id, suffix, this);
-    m_dragVal->setRange(min, max);
-    m_dragVal->setPrecision(0);
+    m_dragVal = new DragValue(name, defaultValue, decimals, min, max, id, suffix, this);
     layout->addWidget(m_dragVal, 0, 1);
 
     if (!comment.isEmpty()) {
@@ -55,7 +54,7 @@ DoubleParameterWidget::DoubleParameterWidget(const QString &name, int value, int
         layout->addWidget(m_commentLabel, 1, 0, 1, -1);
     }
     m_dragVal->setValue(value);
-    connect(m_dragVal, SIGNAL(valueChanged(int, bool)), this, SLOT(slotSetValue(int, bool)));
+    connect(m_dragVal, SIGNAL(valueChanged(double, bool)), this, SLOT(slotSetValue(double, bool)));
     connect(m_dragVal, SIGNAL(inTimeline(int)), this, SIGNAL(setInTimeline(int)));
 }
 
@@ -69,21 +68,21 @@ void DoubleParameterWidget::setSpinSize(int width)
     m_dragVal->setSpinSize(width);
 }
 
-void DoubleParameterWidget::setValue(int value)
+void DoubleParameterWidget::setValue(double value)
 {
     m_dragVal->blockSignals(true);
     m_dragVal->setValue(value);
     m_dragVal->blockSignals(false);
 }
 
-void DoubleParameterWidget::slotSetValue(int value, bool final)
+void DoubleParameterWidget::slotSetValue(double value, bool final)
 {
     if (final) {
         emit valueChanged(value);
     }
 }
 
-int DoubleParameterWidget::getValue()
+double DoubleParameterWidget::getValue()
 {
     return m_dragVal->value();
 }
