@@ -25,14 +25,12 @@
 #include <KIcon>
 #include <KLocale>
 #include <KDebug>
-#include <KColorScheme>
 
 #include <QMouseEvent>
 #include <QWidget>
 #include <QPainter>
 #include <QAction>
 #include <QTimer>
-#include <QColor>
 #include <QDomDocument>
 
 HeaderTrack::HeaderTrack(int index, TrackInfo info, int height, QWidget *parent) :
@@ -44,16 +42,6 @@ HeaderTrack::HeaderTrack(int index, TrackInfo info, int height, QWidget *parent)
     setFixedHeight(height);
     setupUi(this);
 
-    QPalette p = palette();
-    KColorScheme scheme(p.currentColorGroup(), KColorScheme::View, KSharedConfig::openConfig(KdenliveSettings::colortheme()));
-    QColor norm = scheme.shade(scheme.background(KColorScheme::ActiveBackground).color(), KColorScheme::MidShade);
-    p.setColor(QPalette::Button, norm);
-    setPalette(p);
-
-    QColor col = scheme.background().color();
-    QColor col2 = scheme.foreground().color();
-    track_number->setStyleSheet(QString("QLineEdit { background-color: transparent;color: rgb(%4, %5, %6);} QLineEdit:hover{ background-color: rgb(%1, %2, %3);} QLineEdit:focus { background-color: rgb(%1, %2, %3);}").arg(col.red()).arg(col.green()).arg(col.blue()).arg(col2.red()).arg(col2.green()).arg(col2.blue()));
-
     m_name = info.trackName.isEmpty() ? QString::number(m_index) : info.trackName;
     track_number->setText(m_name);
     connect(track_number, SIGNAL(editingFinished()), this, SLOT(slotRenameTrack()));
@@ -120,7 +108,6 @@ HeaderTrack::HeaderTrack(int index, TrackInfo info, int height, QWidget *parent)
 
 void HeaderTrack::updateEffectLabel(QStringList effects)
 {
-    QColor col = track_number->palette().color(QPalette::Base);
     if (!effects.isEmpty()) {
         effect_label->setHidden(false);
         effect_label->setToolTip(effects.join("/"));
@@ -181,8 +168,18 @@ void HeaderTrack::dropEvent(QDropEvent * event)
 //virtual
 void HeaderTrack::dragEnterEvent(QDragEnterEvent *event)
 {
-    if (buttonLock->isChecked()) event->setAccepted(false);
-    else event->setAccepted(event->mimeData()->hasFormat("kdenlive/effectslist"));
+    if (buttonLock->isChecked()) {
+        event->setAccepted(false);
+    } else {
+        if (event->mimeData()->hasFormat("kdenlive/effectslist")) {
+            const QString effects = QString::fromUtf8(event->mimeData()->data("kdenlive/effectslist"));
+            QDomDocument doc;
+            doc.setContent(effects, true);
+            if (doc.documentElement().attribute("id") != "speed") {
+                event->setAccepted(true);
+            }
+        }
+    }
 }
 
 void HeaderTrack::setSelectedIndex(int ix)
