@@ -39,6 +39,7 @@
 #include <KFileDialog>
 #include <KIO/NetAccess>
 #include <KIO/CopyJob>
+#include <KIO/JobUiDelegate>
 #include <KApplication>
 #include <KGlobal>
 #include <KBookmarkManager>
@@ -52,9 +53,12 @@
 
 #include <mlt++/Mlt.h>
 
-const double DOCUMENTVERSION = 0.85;
+#include "locale.h"
 
-KdenliveDoc::KdenliveDoc(const KUrl &url, const KUrl &projectFolder, QUndoGroup *undoGroup, QString profileName, QMap <QString, QString> properties, const QPoint tracks, Render *render, KTextEdit *notes, MainWindow *parent, KProgressDialog *progressDialog) :
+
+const double DOCUMENTVERSION = 0.88;
+
+KdenliveDoc::KdenliveDoc(const KUrl &url, const KUrl &projectFolder, QUndoGroup *undoGroup, QString profileName, QMap <QString, QString> properties, const QPoint &tracks, Render *render, KTextEdit *notes, bool *openBackup, MainWindow *parent, KProgressDialog *progressDialog) :
     QObject(parent),
     m_autosave(NULL),
     m_url(url),
@@ -64,6 +68,18 @@ KdenliveDoc::KdenliveDoc(const KUrl &url, const KUrl &projectFolder, QUndoGroup
     m_modified(false),
     m_projectFolder(projectFolder)
 {
+    // init m_profile struct
+    m_profile.frame_rate_num = 0;
+    m_profile.frame_rate_den = 0;
+    m_profile.width = 0;
+    m_profile.height = 0;
+    m_profile.progressive = 0;
+    m_profile.sample_aspect_num = 0;
+    m_profile.sample_aspect_den = 0;
+    m_profile.display_aspect_num = 0;
+    m_profile.display_aspect_den = 0;
+    m_profile.colorspace = 0;
+
     m_clipManager = new ClipManager(this);
     m_autoSaveTimer = new QTimer(this);
     m_autoSaveTimer->setSingleShot(true);
@@ -81,19 +97,41 @@ KdenliveDoc::KdenliveDoc(const KUrl &url, const KUrl &projectFolder, QUndoGroup
     m_documentProperties["proxyminsize"] = QString::number(KdenliveSettings::proxyminsize());
     m_documentProperties["generateimageproxy"] = QString::number((int) KdenliveSettings::generateimageproxy());
     m_documentProperties["proxyimageminsize"] = QString::number(KdenliveSettings::proxyimageminsize());
-    
+#if QT_VERSION >= 0x040700
+    m_documentProperties["documentid"] = QString::number(QDateTime::currentMSecsSinceEpoch());
+#else
+    QDateTime date = QDateTime::currentDateTime();
+    m_documentProperties["documentid"] = QString::number(date.toTime_t());
+#endif
+
     // Load properties
     QMapIterator<QString, QString> i(properties);
     while (i.hasNext()) {
         i.next();
         m_documentProperties[i.key()] = i.value();
     }
+
+    if (QLocale().decimalPoint() != QLocale::system().decimalPoint()) {
+        setlocale(LC_NUMERIC, "");
+        QLocale systemLocale = QLocale::system();
+        systemLocale.setNumberOptions(QLocale::OmitGroupSeparator);
+        QLocale::setDefault(systemLocale);
+        // locale conversion might need to be redone
+        initEffects::parseEffectFiles();
+    }
+
+    *openBackup = false;
     
     if (!url.isEmpty()) {
         QString tmpFile;
         success = KIO::NetAccess::download(url.path(), tmpFile, parent);
-        if (!success) // The file cannot be opened
-            KMessageBox::error(parent, KIO::NetAccess::lastErrorString());
+        if (!success) {
+            // The file cannot be opened
+            if (KMessageBox::warningContinueCancel(parent, i18n("Cannot open the project file, error is:\n%1\nDo you want to open a backup file?", KIO::NetAccess::lastErrorString()), i18n("Error opening file"), KGuiItem(i18n("Open Backup"))) == KMessageBox::Continue) {
+                *openBackup = true;
+            }
+            //KMessageBox::error(parent, KIO::NetAccess::lastErrorString());
+        }
         else {
             QFile file(tmpFile);
             QString errorMsg;
@@ -103,8 +141,13 @@ KdenliveDoc::KdenliveDoc(const KUrl &url, const KUrl &projectFolder, QUndoGroup
             file.close();
             KIO::NetAccess::removeTempFile(tmpFile);
 
-            if (!success) // It is corrupted
-                KMessageBox::error(parent, errorMsg);
+            if (!success) {
+                // It is corrupted
+                if (KMessageBox::warningContinueCancel(parent, i18n("Cannot open the project file, error is:\n%1\nDo you want to open a backup file?", errorMsg), i18n("Error opening file"), KGuiItem(i18n("Open Backup"))) == KMessageBox::Continue) {
+                *openBackup = true;
+            }
+                //KMessageBox::error(parent, errorMsg);
+            }
             else {
                 parent->slotGotProgressInfo(i18n("Validating"), 0);
                 qApp->processEvents();
@@ -113,6 +156,9 @@ KdenliveDoc::KdenliveDoc(const KUrl &url, const KUrl &projectFolder, QUndoGroup
                 if (!success) {
                     // It is not a project file
                     parent->slotGotProgressInfo(i18n("File %1 is not a Kdenlive project file", m_url.path()), 100);
+                    if (KMessageBox::warningContinueCancel(parent, i18n("File %1 is not a valid project file.\nDo you want to open a backup file?", m_url.path()), i18n("Error opening file"), KGuiItem(i18n("Open Backup"))) == KMessageBox::Continue) {
+                        *openBackup = true;
+                    }
                 } else {
                     /*
                      * Validate the file against the current version (upgrade
@@ -131,6 +177,9 @@ KdenliveDoc::KdenliveDoc(const KUrl &url, const KUrl &projectFolder, QUndoGroup
                             QDomElement mlt = m_document.firstChildElement("mlt");
                             QDomElement infoXml = mlt.firstChildElement("kdenlivedoc");
 
+                            // Set profile, fps, etc for the document
+                            setProfilePath(infoXml.attribute("profile"));
+
                             // Check embedded effects
                             QDomElement customeffects = infoXml.firstChildElement("customeffects");
                             if (!customeffects.isNull() && customeffects.hasChildNodes()) {
@@ -236,7 +285,7 @@ KdenliveDoc::KdenliveDoc(const KUrl &url, const KUrl &projectFolder, QUndoGroup
                                 QDomNamedNodeMap props = docproperties.attributes();
                                 for (int i = 0; i < props.count(); i++)
                                     m_documentProperties.insert(props.item(i).nodeName(), props.item(i).nodeValue());
-                                setProfilePath(infoXml.attribute("profile"));
+
                                 if (validator.isModified()) setModified(true);
                                 kDebug() << "Reading file: " << url.path() << ", found clips: " << producers.count();
                             }
@@ -246,17 +295,14 @@ KdenliveDoc::KdenliveDoc(const KUrl &url, const KUrl &projectFolder, QUndoGroup
             }
         }
     }
-
+    
     // Something went wrong, or a new file was requested: create a new project
     if (!success) {
-        m_url = KUrl();
+        m_url.clear();
         setProfilePath(profileName);
         m_document = createEmptyDocument(tracks.x(), tracks.y());
     }
 
-    // Set the video profile (empty == default)
-    KdenliveSettings::setCurrent_profile(profilePath());
-
     // Ask to create the project directory if it does not exist
     if (!QFile::exists(m_projectFolder.path())) {
         int create = KMessageBox::questionYesNo(parent, i18n("Project directory %1 does not exist. Create it?", m_projectFolder.path()));
@@ -278,7 +324,6 @@ KdenliveDoc::KdenliveDoc(const KUrl &url, const KUrl &projectFolder, QUndoGroup
     // Make sure that the necessary folders exist
     KStandardDirs::makeDir(m_projectFolder.path(KUrl::AddTrailingSlash) + "titles/");
     KStandardDirs::makeDir(m_projectFolder.path(KUrl::AddTrailingSlash) + "thumbs/");
-    KStandardDirs::makeDir(m_projectFolder.path(KUrl::AddTrailingSlash) + "ladspa/");
     KStandardDirs::makeDir(m_projectFolder.path(KUrl::AddTrailingSlash) + "proxy/");
 
     updateProjectFolderPlacesEntry();
@@ -303,7 +348,7 @@ KdenliveDoc::~KdenliveDoc()
 
 int KdenliveDoc::setSceneList()
 {
-    m_render->resetProfile(KdenliveSettings::current_profile());
+    m_render->resetProfile(KdenliveSettings::current_profile(), true);
     if (m_render->setSceneList(m_document.toString(), m_documentProperties.value("position").toInt()) == -1) {
         // INVALID MLT Consumer, something is wrong
         return -1;
@@ -350,9 +395,9 @@ QDomDocument KdenliveDoc::createEmptyDocument(QList <TrackInfo> tracks)
     // Creating new document
     QDomDocument doc;
     QDomElement mlt = doc.createElement("mlt");
+    mlt.setAttribute("LC_NUMERIC", "");
     doc.appendChild(mlt);
-
-
+    
     // Create black producer
     // For some unknown reason, we have to build the black producer here and not in renderer.cpp, otherwise
     // the composite transitions with the black track are corrupted.
@@ -369,7 +414,7 @@ QDomDocument KdenliveDoc::createEmptyDocument(QList <TrackInfo> tracks)
 
     property = doc.createElement("property");
     property.setAttribute("name", "aspect_ratio");
-    value = doc.createTextNode(QString::number(0.0));
+    value = doc.createTextNode(QString::number(0));
     property.appendChild(value);
     blk.appendChild(property);
 
@@ -509,7 +554,7 @@ void KdenliveDoc::slotAutoSave()
             kDebug() << "ERROR; CANNOT CREATE AUTOSAVE FILE";
         }
         kDebug() << "// AUTOSAVE FILE: " << m_autosave->fileName();
-        saveSceneList(m_autosave->fileName(), m_render->sceneList(), QStringList());
+        saveSceneList(m_autosave->fileName(), m_render->sceneList(), QStringList(), true);
     }
 }
 
@@ -535,15 +580,26 @@ QPoint KdenliveDoc::zone() const
     return QPoint(m_documentProperties.value("zonein").toInt(), m_documentProperties.value("zoneout").toInt());
 }
 
-bool KdenliveDoc::saveSceneList(const QString &path, const QString &scene, const QStringList expandedFolders)
+QDomDocument KdenliveDoc::xmlSceneList(const QString &scene, const QStringList &expandedFolders)
 {
     QDomDocument sceneList;
     sceneList.setContent(scene, true);
     QDomElement mlt = sceneList.firstChildElement("mlt");
     if (mlt.isNull() || !mlt.hasChildNodes()) {
-        //Make sure we don't save if scenelist is corrupted
-        KMessageBox::error(kapp->activeWindow(), i18n("Cannot write to file %1, scene list is corrupted.", path));
-        return false;
+        //scenelist is corrupted
+        return sceneList;
+    }
+
+    // Set playlist audio volume to 100%
+    QDomElement tractor = mlt.firstChildElement("tractor");
+    if (!tractor.isNull()) {
+        QDomNodeList props = tractor.elementsByTagName("property");
+        for (int i = 0; i < props.count(); i++) {
+            if (props.at(i).toElement().attribute("name") == "meta.volume") {
+                props.at(i).firstChild().setNodeValue("1");
+                break;
+            }
+        }
     }
 
     QDomElement addedXml = sceneList.createElement("kdenlivedoc");
@@ -589,7 +645,7 @@ bool KdenliveDoc::saveSceneList(const QString &path, const QString &scene, const
     addedXml.appendChild(docproperties);
 
     QDomElement docnotes = sceneList.createElement("documentnotes");
-    QDomText value = sceneList.createTextNode(m_notesWidget->toPlainText());
+    QDomText value = sceneList.createTextNode(m_notesWidget->toHtml());
     docnotes.appendChild(value);
     addedXml.appendChild(docnotes);
 
@@ -658,8 +714,22 @@ bool KdenliveDoc::saveSceneList(const QString &path, const QString &scene, const
     addedXml.appendChild(sceneList.importNode(m_clipManager->groupsXml(), true));
 
     //wes.appendChild(doc.importNode(kdenliveData, true));
+    return sceneList;
+}
 
+bool KdenliveDoc::saveSceneList(const QString &path, const QString &scene, const QStringList &expandedFolders, bool autosave)
+{
+    QDomDocument sceneList = xmlSceneList(scene, expandedFolders);
+    if (sceneList.isNull()) {
+        //Make sure we don't save if scenelist is corrupted
+        KMessageBox::error(kapp->activeWindow(), i18n("Cannot write to file %1, scene list is corrupted.", path));
+        return false;
+    }
+    
+    // Backup current version
+    if (!autosave) backupLastSavedVersion(path);
     QFile file(path);
+    
     if (!file.open(QIODevice::WriteOnly | QIODevice::Text)) {
         kWarning() << "//////  ERROR writing to file: " << path;
         KMessageBox::error(kapp->activeWindow(), i18n("Cannot write to file %1", path));
@@ -673,6 +743,18 @@ bool KdenliveDoc::saveSceneList(const QString &path, const QString &scene, const
         return false;
     }
     file.close();
+    if (!autosave) {
+        cleanupBackupFiles();
+        QFileInfo info(file);
+        QString fileName = KUrl(path).fileName().section('.', 0, -2);   
+        fileName.append("-" + m_documentProperties.value("documentid"));
+        fileName.append(info.lastModified().toString("-yyyy-MM-dd-hh-mm"));
+        fileName.append(".kdenlive.png");
+        KUrl backupFile = m_projectFolder;
+        backupFile.addPath(".backup/");
+        backupFile.addPath(fileName);
+        emit saveTimelinePreview(backupFile.path());
+    }
     return true;
 }
 
@@ -703,7 +785,7 @@ void KdenliveDoc::setProjectFolder(KUrl url)
 void KdenliveDoc::moveProjectData(KUrl url)
 {
     QList <DocClipBase*> list = m_clipManager->documentClipList();
-    //TODO: Also move ladspa effects files
+    KUrl::List cacheUrls;
     for (int i = 0; i < list.count(); i++) {
         DocClipBase *clip = list.at(i);
         if (clip->clipType() == TEXT) {
@@ -717,16 +799,17 @@ void KdenliveDoc::moveProjectData(KUrl url)
         KUrl oldVideoThumbUrl = KUrl(m_projectFolder.path(KUrl::AddTrailingSlash) + "thumbs/" + hash + ".png");
         KUrl oldAudioThumbUrl = KUrl(m_projectFolder.path(KUrl::AddTrailingSlash) + "thumbs/" + hash + ".thumb");
         if (KIO::NetAccess::exists(oldVideoThumbUrl, KIO::NetAccess::SourceSide, 0)) {
-            KUrl newUrl = KUrl(url.path(KUrl::AddTrailingSlash) + "thumbs/" + hash + ".png");
-            KIO::Job *job = KIO::copy(oldVideoThumbUrl, newUrl);
-            KIO::NetAccess::synchronousRun(job, 0);
+            cacheUrls << oldVideoThumbUrl;
         }
         if (KIO::NetAccess::exists(oldAudioThumbUrl, KIO::NetAccess::SourceSide, 0)) {
-            KUrl newUrl = KUrl(url.path(KUrl::AddTrailingSlash) + "thumbs/" + hash + ".thumb");
-            KIO::Job *job = KIO::copy(oldAudioThumbUrl, newUrl);
-            if (KIO::NetAccess::synchronousRun(job, 0)) clip->refreshThumbUrl();
+            cacheUrls << oldAudioThumbUrl;
         }
     }
+    if (!cacheUrls.isEmpty()) {
+        KIO::Job *job = KIO::copy(cacheUrls, KUrl(url.path(KUrl::AddTrailingSlash) + "thumbs/"));
+        job->ui()->setWindow(kapp->activeWindow());
+        KIO::NetAccess::synchronousRun(job, 0);
+    }
 }
 
 const QString &KdenliveDoc::profilePath() const
@@ -796,6 +879,7 @@ bool KdenliveDoc::setProfilePath(QString path)
     m_height = m_profile.height;
     kDebug() << "Kdenlive document, init timecode from path: " << path << ",  " << m_fps;
     m_timecode.setFormat(m_fps);
+    KdenliveSettings::setCurrent_profile(m_profile.path);
     return (current_fps != m_fps);
 }
 
@@ -828,10 +912,10 @@ void KdenliveDoc::setRenderer(Render *render) {
     emit progressInfo(QString(), -1);
 }*/
 
-void KdenliveDoc::checkProjectClips()
+void KdenliveDoc::checkProjectClips(bool displayRatioChanged, bool fpsChanged)
 {
     if (m_render == NULL) return;
-    m_clipManager->resetProducersList(m_render->producersList());
+    m_clipManager->resetProducersList(m_render->producersList(), displayRatioChanged, fpsChanged);
 }
 
 Render *KdenliveDoc::renderer()
@@ -839,7 +923,7 @@ Render *KdenliveDoc::renderer()
     return m_render;
 }
 
-void KdenliveDoc::updateClip(const QString id)
+void KdenliveDoc::updateClip(const QString &id)
 {
     emit updateClipDisplay(id);
 }
@@ -1108,7 +1192,7 @@ void KdenliveDoc::deleteClip(const QString &clipId)
     emit signalDeleteProjectClip(clipId);
 }
 
-void KdenliveDoc::slotAddClipList(const KUrl::List urls, const QString group, const QString &groupId)
+void KdenliveDoc::slotAddClipList(const KUrl::List urls, const QString &group, const QString &groupId)
 {
     m_clipManager->slotAddClipList(urls, group, groupId);
     //emit selectLastAddedClip(QString::number(m_clipManager->lastClipId()));
@@ -1116,7 +1200,7 @@ void KdenliveDoc::slotAddClipList(const KUrl::List urls, const QString group, co
 }
 
 
-void KdenliveDoc::slotAddClipFile(const KUrl url, const QString group, const QString &groupId)
+void KdenliveDoc::slotAddClipFile(const KUrl &url, const QString &group, const QString &groupId)
 {
     m_clipManager->slotAddClipFile(url, group, groupId);
     emit selectLastAddedClip(QString::number(m_clipManager->lastClipId()));
@@ -1147,7 +1231,7 @@ void KdenliveDoc::slotCreateColorClip(const QString &name, const QString &color,
     emit selectLastAddedClip(QString::number(m_clipManager->lastClipId()));
 }
 
-void KdenliveDoc::slotCreateSlideshowClipFile(const QString name, const QString path, int count, const QString duration,
+void KdenliveDoc::slotCreateSlideshowClipFile(const QString &name, const QString &path, int count, const QString &duration,
         const bool loop, const bool crop, const bool fade,
         const QString &luma_duration, const QString &luma_file, const int softness,
         const QString &animation, QString group, const QString &groupId)
@@ -1297,21 +1381,10 @@ void KdenliveDoc::cachePixmap(const QString &fileId, const QPixmap &pix) const
     pix.save(m_projectFolder.path(KUrl::AddTrailingSlash) + "thumbs/" + fileId + ".png");
 }
 
-QString KdenliveDoc::getLadspaFile() const
-{
-    int ct = 0;
-    QString counter = QString::number(ct).rightJustified(5, '0', false);
-    while (QFile::exists(m_projectFolder.path(KUrl::AddTrailingSlash) + "ladspa/" + counter + ".ladspa")) {
-        ct++;
-        counter = QString::number(ct).rightJustified(5, '0', false);
-    }
-    return m_projectFolder.path(KUrl::AddTrailingSlash) + "ladspa/" + counter + ".ladspa";
-}
-
 bool KdenliveDoc::checkDocumentClips(QDomNodeList infoproducers)
 {
     DocumentChecker d(infoproducers, m_document);
-    return (d.hasMissingClips() == false);
+    return (d.hasErrorInClips() == false);
 
     /*    int clipType;
         QDomElement e;
@@ -1380,7 +1453,7 @@ void KdenliveDoc::addTrackEffect(int ix, QDomElement effect)
         QDomElement e = params.item(i).toElement();
 
         // Check if this effect has a variable parameter
-        if (e.attribute("default").startsWith('%')) {
+        if (e.attribute("default").contains('%')) {
             double evaluatedValue = ProfilesDialog::getStringEval(m_profile, e.attribute("default"));
             e.setAttribute("default", evaluatedValue);
             if (e.hasAttribute("value") && e.attribute("value").startsWith('%')) {
@@ -1501,7 +1574,9 @@ void KdenliveDoc::updateProjectFolderPlacesEntry()
 
     const QString file = KStandardDirs::locateLocal("data", "kfileplaces/bookmarks.xml");
     KBookmarkManager *bookmarkManager = KBookmarkManager::managerForFile(file, "kfilePlaces");
+    if (!bookmarkManager) return;
     KBookmarkGroup root = bookmarkManager->root();
+    
     KBookmark bookmark = root.first();
 
     QString kdenliveName = KGlobal::mainComponent().componentName();
@@ -1533,6 +1608,7 @@ void KdenliveDoc::updateProjectFolderPlacesEntry()
         bookmark.setMetaDataItem("OnlyInApp", kdenliveName);
         bookmarkManager->emitChanged(root);
     }
+    delete bookmarkManager;
 }
 
 QStringList KdenliveDoc::getExpandedFolders()
@@ -1543,5 +1619,148 @@ QStringList KdenliveDoc::getExpandedFolders()
     return result;
 }
 
+// static
+double KdenliveDoc::getDisplayRatio(const QString &path)
+{
+    QFile file(path);
+    QDomDocument doc;
+    if (!file.open(QIODevice::ReadOnly)) {
+        kWarning() << "ERROR, CANNOT READ: " << path;
+        return 0;
+    }
+    if (!doc.setContent(&file)) {
+        kWarning() << "ERROR, CANNOT READ: " << path;
+        file.close();
+        return 0;
+    }
+    file.close();
+    QDomNodeList list = doc.elementsByTagName("profile");
+    if (list.isEmpty()) return 0;
+    QDomElement profile = list.at(0).toElement();
+    double den = profile.attribute("display_aspect_den").toDouble();
+    if (den > 0) return profile.attribute("display_aspect_num").toDouble() / den;
+    return 0;
+}
+
+void KdenliveDoc::backupLastSavedVersion(const QString &path)
+{
+    // Ensure backup folder exists
+    if (path.isEmpty()) return;
+    QFile file(path);
+    KUrl backupFile = m_projectFolder;
+    backupFile.addPath(".backup/");
+    KIO::NetAccess::mkdir(backupFile, kapp->activeWindow());
+    QString fileName = KUrl(path).fileName().section('.', 0, -2);
+    QFileInfo info(file);
+    fileName.append("-" + m_documentProperties.value("documentid"));
+    fileName.append(info.lastModified().toString("-yyyy-MM-dd-hh-mm"));
+    fileName.append(".kdenlive");
+    backupFile.addPath(fileName);
+
+    if (file.exists()) {
+        // delete previous backup if it was done less than 60 seconds ago
+        QFile::remove(backupFile.path());
+        if (!QFile::copy(path, backupFile.path())) {
+            KMessageBox::information(kapp->activeWindow(), i18n("Cannot create backup copy:\n%1", backupFile.path()));
+        }
+    }    
+}
+
+void KdenliveDoc::cleanupBackupFiles()
+{
+    KUrl backupFile = m_projectFolder;
+    backupFile.addPath(".backup/");
+    QDir dir(backupFile.path());
+    QString projectFile = url().fileName().section('.', 0, -2);
+    projectFile.append("-" + m_documentProperties.value("documentid"));
+    projectFile.append("-??");
+    projectFile.append("??");
+    projectFile.append("-??");
+    projectFile.append("-??");
+    projectFile.append("-??");
+    projectFile.append("-??.kdenlive");
+
+    QStringList filter;
+    backupFile.addPath(projectFile);
+    filter << projectFile;
+    dir.setNameFilters(filter);
+    QFileInfoList resultList = dir.entryInfoList(QDir::Files, QDir::Time);
+
+    QDateTime d = QDateTime::currentDateTime();
+    QStringList hourList;
+    QStringList dayList;
+    QStringList weekList;
+    QStringList oldList;
+    for (int i = 0; i < resultList.count(); i++) {
+        if (d.secsTo(resultList.at(i).lastModified()) < 3600) {
+            // files created in the last hour
+            hourList.append(resultList.at(i).absoluteFilePath());
+        }
+        else if (d.secsTo(resultList.at(i).lastModified()) < 43200) {
+            // files created in the day
+            dayList.append(resultList.at(i).absoluteFilePath());
+        }
+        else if (d.daysTo(resultList.at(i).lastModified()) < 8) {
+            // files created in the week
+            weekList.append(resultList.at(i).absoluteFilePath());
+        }
+        else {
+            // older files
+            oldList.append(resultList.at(i).absoluteFilePath());
+        }
+    }
+    if (hourList.count() > 20) {
+        int step = hourList.count() / 10;
+        for (int i = 0; i < hourList.count(); i += step) {
+            kDebug()<<"REMOVE AT: "<<i<<", COUNT: "<<hourList.count();
+            hourList.removeAt(i);
+            i--;
+        }
+    } else hourList.clear();
+    if (dayList.count() > 20) {
+        int step = dayList.count() / 10;
+        for (int i = 0; i < dayList.count(); i += step) {
+            dayList.removeAt(i);
+            i--;
+        }
+    } else dayList.clear();
+    if (weekList.count() > 20) {
+        int step = weekList.count() / 10;
+        for (int i = 0; i < weekList.count(); i += step) {
+            weekList.removeAt(i);
+            i--;
+        }
+    } else weekList.clear();
+    if (oldList.count() > 20) {
+        int step = oldList.count() / 10;
+        for (int i = 0; i < oldList.count(); i += step) {
+            oldList.removeAt(i);
+            i--;
+        }
+    } else oldList.clear();
+    
+    QString f;
+    while (hourList.count() > 0) {
+        f = hourList.takeFirst();
+        QFile::remove(f);
+        QFile::remove(f + ".png");
+    }
+    while (dayList.count() > 0) {
+        f = dayList.takeFirst();
+        QFile::remove(f);
+        QFile::remove(f + ".png");
+    }
+    while (weekList.count() > 0) {
+        f = weekList.takeFirst();
+        QFile::remove(f);
+        QFile::remove(f + ".png");
+    }
+    while (oldList.count() > 0) {
+        f = oldList.takeFirst();
+        QFile::remove(f);
+        QFile::remove(f + ".png");
+    }
+}
+
 #include "kdenlivedoc.moc"
 
