@@ -19,8 +19,11 @@
 
 #include "kdenlivesettingsdialog.h"
 #include "profilesdialog.h"
+#if !defined(Q_OS_FREEBSD) && !defined(Q_OS_KFREEBSD)
 #include "v4l/v4lcapture.h"
+#endif
 #include "blackmagic/devices.h"
+#include "encodingprofilesdialog.h"
 #include "kdenlivesettings.h"
 
 #include <KStandardDirs>
@@ -53,13 +56,15 @@ KdenliveSettingsDialog::KdenliveSettingsDialog(const QMap<QString, QString>& map
     m_shuttleModified(false),
     m_mappable_actions(mappable_actions)
 {
-
+    KdenliveSettings::setV4l_format(0);
     QWidget *p1 = new QWidget;
     m_configMisc.setupUi(p1);
     m_page1 = addPage(p1, i18n("Misc"), "configure");
 
     // Hide multi tab option until Kdenlive really supports it
     m_configMisc.kcfg_activatetabs->setVisible(false);
+    // Hide avformat-novalidate trick, causes crash (bug #2205 and #2206)
+    m_configMisc.kcfg_projectloading_avformatnovalidate->setVisible(false);
 
     QWidget *p8 = new QWidget;
     m_configProject.setupUi(p8);
@@ -68,7 +73,6 @@ KdenliveSettingsDialog::KdenliveSettingsDialog(const QMap<QString, QString>& map
     m_configProject.kcfg_proxyminsize->setEnabled(KdenliveSettings::generateproxy());
     connect(m_configProject.kcfg_generateimageproxy, SIGNAL(toggled(bool)), m_configProject.kcfg_proxyimageminsize, SLOT(setEnabled(bool)));
     m_configProject.kcfg_proxyimageminsize->setEnabled(KdenliveSettings::generateimageproxy());
-    m_configProject.kcfg_proxyparams->setMaximumHeight(QFontMetrics(font()).lineSpacing() * 5);
 
     QWidget *p3 = new QWidget;
     m_configTimeline.setupUi(p3);
@@ -79,7 +83,7 @@ KdenliveSettingsDialog::KdenliveSettingsDialog(const QMap<QString, QString>& map
     m_configEnv.mltpathurl->setMode(KFile::Directory);
     m_configEnv.mltpathurl->lineEdit()->setObjectName("kcfg_mltpath");
     m_configEnv.rendererpathurl->lineEdit()->setObjectName("kcfg_rendererpath");
-    m_configEnv.kcfg_mltthreads->setMaximum(QThread::idealThreadCount());
+    m_configEnv.kcfg_mltthreads->setMaximum( QThread::idealThreadCount() < 4 ? QThread::idealThreadCount() : 3 );
     m_configEnv.tmppathurl->setMode(KFile::Directory);
     m_configEnv.tmppathurl->lineEdit()->setObjectName("kcfg_currenttmpfolder");
     m_configEnv.projecturl->setMode(KFile::Directory);
@@ -93,13 +97,13 @@ KdenliveSettingsDialog::KdenliveSettingsDialog(const QMap<QString, QString>& map
     QWidget *p4 = new QWidget;
     m_configCapture.setupUi(p4);
 
-#if !defined(Q_WS_MAC) && !defined(Q_OS_FREEBSD)
-    V4lCaptureHandler v4l(NULL);
+#if !defined(Q_WS_MAC) && !defined(Q_OS_FREEBSD) && !defined(Q_OS_KFREEBSD)
+
     // Video 4 Linux device detection
     for (int i = 0; i < 10; i++) {
         QString path = "/dev/video" + QString::number(i);
         if (QFile::exists(path)) {
-            QStringList deviceInfo = v4l.getDeviceName(path);
+            QStringList deviceInfo = V4lCaptureHandler::getDeviceName(path.toUtf8().constData());
             if (!deviceInfo.isEmpty()) {
                 m_configCapture.kcfg_detectedv4ldevices->addItem(deviceInfo.at(0), path);
                 m_configCapture.kcfg_detectedv4ldevices->setItemData(m_configCapture.kcfg_detectedv4ldevices->count() - 1, deviceInfo.at(1), Qt::UserRole + 1);
@@ -107,6 +111,11 @@ KdenliveSettingsDialog::KdenliveSettingsDialog(const QMap<QString, QString>& map
         }
     }
     connect(m_configCapture.kcfg_detectedv4ldevices, SIGNAL(currentIndexChanged(int)), this, SLOT(slotUpdatev4lDevice()));
+    connect(m_configCapture.kcfg_v4l_format, SIGNAL(currentIndexChanged(int)), this, SLOT(slotUpdatev4lCaptureProfile()));
+    connect(m_configCapture.kcfg_v4l_captureaudio, SIGNAL(toggled(bool)), m_configCapture.kcfg_v4l_alsadevice, SLOT(setEnabled(bool)));
+    connect(m_configCapture.config_v4l, SIGNAL(clicked()), this, SLOT(slotEditVideo4LinuxProfile()));
+
+    slotUpdatev4lDevice();
 #endif
 
     m_page4 = addPage(p4, i18n("Capture"), "media-record");
@@ -180,15 +189,6 @@ KdenliveSettingsDialog::KdenliveSettingsDialog(const QMap<QString, QString>& map
     connect(m_configTranscode.button_add, SIGNAL(clicked()), this, SLOT(slotAddTranscode()));
     connect(m_configTranscode.button_delete, SIGNAL(clicked()), this, SLOT(slotDeleteTranscode()));
     connect(m_configTranscode.profiles_list, SIGNAL(itemChanged(QTreeWidgetItem *, int)), this, SLOT(slotDialogModified()));
-    
-    connect(m_configCapture.kcfg_video4vdevice, SIGNAL(editingFinished()), this, SLOT(rebuildVideo4Commands()));
-    connect(m_configCapture.kcfg_video4adevice, SIGNAL(editingFinished()), this, SLOT(rebuildVideo4Commands()));
-    connect(m_configCapture.kcfg_video4vcodec, SIGNAL(editingFinished()), this, SLOT(rebuildVideo4Commands()));
-    connect(m_configCapture.kcfg_video4acodec, SIGNAL(editingFinished()), this, SLOT(rebuildVideo4Commands()));
-    connect(m_configCapture.kcfg_video4vformat, SIGNAL(editingFinished()), this, SLOT(rebuildVideo4Commands()));
-    connect(m_configCapture.kcfg_video4aformat, SIGNAL(editingFinished()), this, SLOT(rebuildVideo4Commands()));
-    connect(m_configCapture.kcfg_video4size, SIGNAL(editingFinished()), this, SLOT(rebuildVideo4Commands()));
-    connect(m_configCapture.kcfg_video4rate, SIGNAL(editingFinished()), this, SLOT(rebuildVideo4Commands()));
 
     connect(m_configCapture.kcfg_rmd_capture_audio, SIGNAL(clicked(bool)), m_configCapture.audio_group, SLOT(setVisible(bool)));
 
@@ -198,6 +198,7 @@ KdenliveSettingsDialog::KdenliveSettingsDialog(const QMap<QString, QString>& map
     connect(m_configEnv.kp_audio, SIGNAL(clicked()), this, SLOT(slotEditAudioApplication()));
     connect(m_configEnv.kp_player, SIGNAL(clicked()), this, SLOT(slotEditVideoApplication()));
 
+    loadEncodingProfiles();
     checkProfile();
 
     slotUpdateDisplay();
@@ -219,9 +220,47 @@ KdenliveSettingsDialog::KdenliveSettingsDialog(const QMap<QString, QString>& map
         KdenliveSettings::setDvgrab_path(dvgrabpath);
     }
 
+    // decklink profile
+    m_configCapture.decklink_showprofileinfo->setIcon(KIcon("help-about"));
+    m_configCapture.decklink_manageprofile->setIcon(KIcon("configure"));
+    m_configCapture.decklink_parameters->setVisible(false);
+    m_configCapture.decklink_parameters->setMaximumHeight(QFontMetrics(font()).lineSpacing() * 4);
+    m_configCapture.decklink_parameters->setPlainText(KdenliveSettings::decklink_parameters());
+    connect(m_configCapture.decklink_manageprofile, SIGNAL(clicked(bool)), this, SLOT(slotManageEncodingProfile()));
+    connect(m_configCapture.kcfg_decklink_profile, SIGNAL(currentIndexChanged(int)), this, SLOT(slotUpdateDecklinkProfile()));
+    connect(m_configCapture.decklink_showprofileinfo, SIGNAL(clicked(bool)), m_configCapture.decklink_parameters, SLOT(setVisible(bool)));
 
-    BMInterface::getBlackMagicDeviceList(m_configCapture.kcfg_hdmi_capturedevice, m_configCapture.kcfg_hdmi_capturemode);
-    connect(m_configCapture.kcfg_hdmi_capturedevice, SIGNAL(currentIndexChanged(int)), this, SLOT(slotUpdateHDMIModes()));
+    // v4l profile
+    m_configCapture.v4l_showprofileinfo->setIcon(KIcon("help-about"));
+    m_configCapture.v4l_manageprofile->setIcon(KIcon("configure"));
+    m_configCapture.v4l_parameters->setVisible(false);
+    m_configCapture.v4l_parameters->setMaximumHeight(QFontMetrics(font()).lineSpacing() * 4);
+    m_configCapture.v4l_parameters->setPlainText(KdenliveSettings::v4l_parameters());
+    connect(m_configCapture.v4l_manageprofile, SIGNAL(clicked(bool)), this, SLOT(slotManageEncodingProfile()));
+    connect(m_configCapture.kcfg_v4l_profile, SIGNAL(currentIndexChanged(int)), this, SLOT(slotUpdateV4lProfile()));
+    connect(m_configCapture.v4l_showprofileinfo, SIGNAL(clicked(bool)), m_configCapture.v4l_parameters, SLOT(setVisible(bool)));
+
+    // proxy profile stuff
+    m_configProject.proxy_showprofileinfo->setIcon(KIcon("help-about"));
+    m_configProject.proxy_manageprofile->setIcon(KIcon("configure"));
+    m_configProject.proxyparams->setVisible(false);
+    m_configProject.proxyparams->setMaximumHeight(QFontMetrics(font()).lineSpacing() * 4);
+    m_configProject.proxyparams->setPlainText(KdenliveSettings::proxyparams());
+    connect(m_configProject.proxy_manageprofile, SIGNAL(clicked(bool)), this, SLOT(slotManageEncodingProfile()));
+    connect(m_configProject.proxy_showprofileinfo, SIGNAL(clicked(bool)), m_configProject.proxyparams, SLOT(setVisible(bool)));
+    connect(m_configProject.kcfg_proxy_profile, SIGNAL(currentIndexChanged(int)), this, SLOT(slotUpdateProxyProfile()));
+
+
+    slotUpdateProxyProfile(-1);
+    slotUpdateV4lProfile(-1);
+    slotUpdateDecklinkProfile(-1);
+
+    BMInterface::getBlackMagicDeviceList(m_configCapture.kcfg_decklink_capturedevice);
+    if (m_configCapture.kcfg_decklink_capturedevice->count() > 0) {
+        QStringList modes = m_configCapture.kcfg_decklink_capturedevice->itemData(m_configCapture.kcfg_decklink_capturedevice->currentIndex()).toStringList();
+        m_configCapture.kcfg_decklink_capturedevice->setToolTip(i18n("Supported capture modes:\n") + modes.join("\n"));
+    }
+    connect(m_configCapture.kcfg_decklink_capturedevice, SIGNAL(currentIndexChanged(int)), this, SLOT(slotUpdateHDMIModes()));
 
     if (BMInterface::getBlackMagicOutputDeviceList(m_configSdl.kcfg_blackmagic_output_device)) {
         // Found blackmagic card
@@ -261,9 +300,8 @@ KdenliveSettingsDialog::~KdenliveSettingsDialog() {}
 
 void KdenliveSettingsDialog::slotUpdateHDMIModes()
 {
-    QStringList modes = m_configCapture.kcfg_hdmi_capturedevice->itemData(m_configCapture.kcfg_hdmi_capturedevice->currentIndex()).toStringList();
-    m_configCapture.kcfg_hdmi_capturemode->clear();
-    m_configCapture.kcfg_hdmi_capturemode->insertItems(0, modes);
+    QStringList modes = m_configCapture.kcfg_decklink_capturedevice->itemData(m_configCapture.kcfg_decklink_capturedevice->currentIndex()).toStringList();
+    m_configCapture.kcfg_decklink_capturedevice->setToolTip(i18n("Supported capture modes:\n") + modes.join("\n"));
 }
 
 void KdenliveSettingsDialog::slotUpdateRmdRegionStatus()
@@ -356,6 +394,7 @@ void KdenliveSettingsDialog::initDevices()
                 if (line.contains("capture")) {
                     deviceId = line.section(':', 0, 0);
                     m_configCapture.kcfg_rmd_alsa_device->addItem(line.section(':', 1, 1), "plughw:" + QString::number(deviceId.section('-', 0, 0).toInt()) + ',' + QString::number(deviceId.section('-', 1, 1).toInt()));
+                    m_configCapture.kcfg_v4l_alsadevice->addItem(line.section(':', 1, 1), "hw:" + QString::number(deviceId.section('-', 0, 0).toInt()) + ',' + QString::number(deviceId.section('-', 1, 1).toInt()));
                 }
             }
             file.close();
@@ -367,12 +406,22 @@ void KdenliveSettingsDialog::initDevices()
         m_configSdl.kcfg_audio_device->setCurrentIndex(ix);
         KdenliveSettings::setAudio_device(ix);
     }
+
     if (!KdenliveSettings::rmd_alsadevicename().isEmpty()) {
         // Select correct alsa device
         int ix = m_configCapture.kcfg_rmd_alsa_device->findData(KdenliveSettings::rmd_alsadevicename());
         m_configCapture.kcfg_rmd_alsa_device->setCurrentIndex(ix);
         KdenliveSettings::setRmd_alsa_device(ix);
     }
+
+    if (!KdenliveSettings::v4l_alsadevicename().isEmpty()) {
+        // Select correct alsa device
+        int ix = m_configCapture.kcfg_v4l_alsadevice->findData(KdenliveSettings::v4l_alsadevicename());
+        m_configCapture.kcfg_v4l_alsadevice->setCurrentIndex(ix);
+        KdenliveSettings::setV4l_alsadevice(ix);
+    }
+
+    loadCurrentV4lProfileInfo();
 }
 
 
@@ -383,12 +432,13 @@ void KdenliveSettingsDialog::slotReadAudioDevices()
     kDebug() << result;
     QStringList lines = result.split('\n');
     foreach(const QString & data, lines) {
-        kDebug() << "// READING LINE: " << data;
-        if (data.simplified().startsWith("card")) {
+        //kDebug() << "// READING LINE: " << data;
+        if (!data.startsWith(" ") && data.count(':') > 1) {
             QString card = data.section(':', 0, 0).section(' ', -1);
             QString device = data.section(':', 1, 1).section(' ', -1);
             m_configSdl.kcfg_audio_device->addItem(data.section(':', -1), "plughw:" + card + ',' + device);
             m_configCapture.kcfg_rmd_alsa_device->addItem(data.section(':', -1), "plughw:" + card + ',' + device);
+            m_configCapture.kcfg_v4l_alsadevice->addItem(data.section(':', -1), "hw:" + card + ',' + device);
         }
     }
 }
@@ -488,14 +538,6 @@ void KdenliveSettingsDialog::slotUpdateShuttleDevice(int ix)
 
 #endif /* NO_JOGSHUTTLE */
 
-void KdenliveSettingsDialog::rebuildVideo4Commands()
-{
-    QString captureCommand;
-    if (!m_configCapture.kcfg_video4adevice->text().isEmpty()) captureCommand = "-f " + m_configCapture.kcfg_video4aformat->text() + " -i " + m_configCapture.kcfg_video4adevice->text() + " -acodec " + m_configCapture.kcfg_video4acodec->text();
-
-    captureCommand +=  " -f " + m_configCapture.kcfg_video4vformat->text() + " -s " + m_configCapture.kcfg_video4size->text() + " -r " + QString::number(m_configCapture.kcfg_video4rate->value()) + " -i " + m_configCapture.kcfg_video4vdevice->text() + " -vcodec " + m_configCapture.kcfg_video4vcodec->text();
-    m_configCapture.kcfg_video4capture->setText(captureCommand);
-}
 void KdenliveSettingsDialog::updateWidgets()
 {
     // Revert widgets to last saved state (for example when user pressed "Cancel")
@@ -543,7 +585,7 @@ void KdenliveSettingsDialog::updateSettings()
 
     bool resetProfile = false;
     bool updateCapturePath = false;
-    
+
     /*if (m_configShuttle.shuttledevicelist->count() > 0) {
 	QString device = m_configShuttle.shuttledevicelist->itemData(m_configShuttle.shuttledevicelist->currentIndex()).toString();
 	if (device != KdenliveSettings::shuttledevice()) KdenliveSettings::setShuttledevice(device);
@@ -569,6 +611,29 @@ void KdenliveSettingsDialog::updateSettings()
         updateCapturePath = true;
     }
 
+    if ((uint) m_configCapture.kcfg_v4l_format->currentIndex() != KdenliveSettings::v4l_format()) {
+        saveCurrentV4lProfile();
+        KdenliveSettings::setV4l_format(0);
+    }
+
+    // Check encoding profiles
+    QString data = m_configCapture.kcfg_v4l_profile->itemData(m_configCapture.kcfg_v4l_profile->currentIndex()).toString();
+    if (!data.isEmpty() && data.section(";", 0, 0) != KdenliveSettings::v4l_parameters()) {
+        KdenliveSettings::setV4l_parameters(data.section(";", 0, 0));
+        KdenliveSettings::setV4l_extension(data.section(";", 1, 1));
+    }
+    data = m_configCapture.kcfg_decklink_profile->itemData(m_configCapture.kcfg_decklink_profile->currentIndex()).toString();
+    if (!data.isEmpty() && data.section(";", 0, 0) != KdenliveSettings::decklink_parameters()) {
+        KdenliveSettings::setDecklink_parameters(data.section(";", 0, 0));
+        KdenliveSettings::setDecklink_extension(data.section(";", 1, 1));
+    }
+    data = m_configProject.kcfg_proxy_profile->itemData(m_configProject.kcfg_proxy_profile->currentIndex()).toString();
+    if (!data.isEmpty() && data.section(";", 0, 0) != KdenliveSettings::proxyparams()) {
+        KdenliveSettings::setProxyparams(data.section(";", 0, 0));
+        KdenliveSettings::setProxyextension(data.section(";", 1, 1));
+    }
+
+
     if (updateCapturePath) emit updateCaptureFolder();
 
     QString value = m_configCapture.kcfg_rmd_alsa_device->itemData(m_configCapture.kcfg_rmd_alsa_device->currentIndex()).toString();
@@ -576,6 +641,11 @@ void KdenliveSettingsDialog::updateSettings()
         KdenliveSettings::setRmd_alsadevicename(value);
     }
 
+    value = m_configCapture.kcfg_v4l_alsadevice->itemData(m_configCapture.kcfg_v4l_alsadevice->currentIndex()).toString();
+    if (value != KdenliveSettings::v4l_alsadevicename()) {
+        KdenliveSettings::setV4l_alsadevicename(value);
+    }
+
     value = m_configCapture.kcfg_rmd_audio_freq->itemText(m_configCapture.kcfg_rmd_audio_freq->currentIndex());
     kDebug() << "// AUDIO FREQ VALUE: " << value << ", CURRENT: " << KdenliveSettings::rmd_freq() << ", IX: " << m_configCapture.kcfg_rmd_audio_freq->currentIndex();
     if (value != KdenliveSettings::rmd_freq()) {
@@ -621,18 +691,6 @@ void KdenliveSettingsDialog::updateSettings()
         KdenliveSettings::setVolume(m_configSdl.kcfg_volume->value());
         resetProfile = true;
     }
-    
-    if (m_configProject.kcfg_enableproxy->isChecked() != KdenliveSettings::enableproxy()) {
-        KdenliveSettings::setEnableproxy(m_configProject.kcfg_enableproxy->isChecked());
-    }
-    
-    if (m_configProject.kcfg_generateproxy->isChecked() != KdenliveSettings::generateproxy()) {
-        KdenliveSettings::setGenerateproxy(m_configProject.kcfg_generateproxy->isChecked());
-    }
-    
-    if (m_configProject.kcfg_proxyminsize->value() != KdenliveSettings::proxyminsize()) {
-        KdenliveSettings::setProxyminsize(m_configProject.kcfg_proxyminsize->value());
-    }
 
     if (m_modified) {
         // The transcoding profiles were modified, save.
@@ -767,11 +825,202 @@ void KdenliveSettingsDialog::slotUpdatev4lDevice()
 {
     QString device = m_configCapture.kcfg_detectedv4ldevices->itemData(m_configCapture.kcfg_detectedv4ldevices->currentIndex()).toString();
     if (!device.isEmpty()) m_configCapture.kcfg_video4vdevice->setText(device);
-    QString size = m_configCapture.kcfg_detectedv4ldevices->itemData(m_configCapture.kcfg_detectedv4ldevices->currentIndex(), Qt::UserRole + 1).toString();
-    if (!size.isEmpty()) m_configCapture.kcfg_video4size->setText(size);
-    rebuildVideo4Commands();
+    QString info = m_configCapture.kcfg_detectedv4ldevices->itemData(m_configCapture.kcfg_detectedv4ldevices->currentIndex(), Qt::UserRole + 1).toString();
+
+    m_configCapture.kcfg_v4l_format->blockSignals(true);
+    m_configCapture.kcfg_v4l_format->clear();
+
+    QString vl4ProfilePath = KStandardDirs::locateLocal("appdata", "profiles/video4linux");
+    if (QFile::exists(vl4ProfilePath)) {
+        m_configCapture.kcfg_v4l_format->addItem(i18n("Current settings"));
+    }
+
+    QStringList pixelformats = info.split(">", QString::SkipEmptyParts);
+    QString itemSize;
+    QString pixelFormat;
+    QStringList itemRates;
+    for (int i = 0; i < pixelformats.count(); i++) {
+        QString format = pixelformats.at(i).section(':', 0, 0);
+        QStringList sizes = pixelformats.at(i).split(":", QString::SkipEmptyParts);
+        pixelFormat = sizes.takeFirst();
+        for (int j = 0; j < sizes.count(); j++) {
+            itemSize = sizes.at(j).section("=", 0, 0);
+            itemRates = sizes.at(j).section("=", 1, 1).split(",", QString::SkipEmptyParts);
+            for (int k = 0; k < itemRates.count(); k++) {
+                m_configCapture.kcfg_v4l_format->addItem("[" + format + "] " + itemSize + " (" + itemRates.at(k) + ")", QStringList() << format << itemSize.section('x', 0, 0) << itemSize.section('x', 1, 1) << itemRates.at(k).section('/', 0, 0) << itemRates.at(k).section('/', 1, 1));
+            }
+        }
+    }
+    m_configCapture.kcfg_v4l_format->blockSignals(false);
+    slotUpdatev4lCaptureProfile();
 }
 
+void KdenliveSettingsDialog::slotUpdatev4lCaptureProfile()
+{
+    QStringList info = m_configCapture.kcfg_v4l_format->itemData(m_configCapture.kcfg_v4l_format->currentIndex(), Qt::UserRole).toStringList();
+    if (info.isEmpty()) {
+        // No auto info, display the current ones
+        loadCurrentV4lProfileInfo();
+        return;
+    }
+    m_configCapture.p_size->setText(info.at(1) + 'x' + info.at(2));
+    m_configCapture.p_fps->setText(info.at(3) + '/' + info.at(4));
+    m_configCapture.p_aspect->setText("1/1");
+    m_configCapture.p_display->setText(info.at(1) + '/' + info.at(2));
+    m_configCapture.p_colorspace->setText(ProfilesDialog::getColorspaceDescription(601));
+    m_configCapture.p_progressive->setText(i18n("Progressive"));
+
+    QString vl4ProfilePath = KStandardDirs::locateLocal("appdata", "profiles/video4linux");
+    if (!QFile::exists(vl4ProfilePath)) saveCurrentV4lProfile();
+}
+
+void KdenliveSettingsDialog::loadCurrentV4lProfileInfo()
+{
+    QString vl4ProfilePath = KStandardDirs::locateLocal("appdata", "profiles/video4linux");
+    MltVideoProfile prof;
+    if (!QFile::exists(vl4ProfilePath)) {
+        // No default formats found, build one
+        prof.width = 320;
+        prof.height = 200;
+        prof.frame_rate_num = 15;
+        prof.frame_rate_den = 1;
+        prof.display_aspect_num = 4;
+        prof.display_aspect_den = 3;
+        prof.sample_aspect_num = 1;
+        prof.sample_aspect_den = 1;
+        prof.progressive = 1;
+        prof.colorspace = 601;
+        ProfilesDialog::saveProfile(prof, vl4ProfilePath);
+    }
+    else prof = ProfilesDialog::getVideoProfile(vl4ProfilePath);
+    m_configCapture.p_size->setText(QString::number(prof.width) + 'x' + QString::number(prof.height));
+    m_configCapture.p_fps->setText(QString::number(prof.frame_rate_num) + '/' + QString::number(prof.frame_rate_den));
+    m_configCapture.p_aspect->setText(QString::number(prof.sample_aspect_num) + '/' + QString::number(prof.sample_aspect_den));
+    m_configCapture.p_display->setText(QString::number(prof.display_aspect_num) + '/' + QString::number(prof.display_aspect_den));
+    m_configCapture.p_colorspace->setText(ProfilesDialog::getColorspaceDescription(prof.colorspace));
+    if (prof.progressive) m_configCapture.p_progressive->setText(i18n("Progressive"));
+}
+
+void KdenliveSettingsDialog::saveCurrentV4lProfile()
+{
+    MltVideoProfile profile;
+    profile.description = "Video4Linux capture";
+    profile.colorspace = ProfilesDialog::getColorspaceFromDescription(m_configCapture.p_colorspace->text());
+    profile.width = m_configCapture.p_size->text().section('x', 0, 0).toInt();
+    profile.height = m_configCapture.p_size->text().section('x', 1, 1).toInt();
+    profile.sample_aspect_num = m_configCapture.p_aspect->text().section('/', 0, 0).toInt();
+    profile.sample_aspect_den = m_configCapture.p_aspect->text().section('/', 1, 1).toInt();
+    profile.display_aspect_num = m_configCapture.p_display->text().section('/', 0, 0).toInt();
+    profile.display_aspect_den = m_configCapture.p_display->text().section('/', 1, 1).toInt();
+    profile.frame_rate_num = m_configCapture.p_fps->text().section('/', 0, 0).toInt();
+    profile.frame_rate_den = m_configCapture.p_fps->text().section('/', 1, 1).toInt();
+    profile.progressive = m_configCapture.p_progressive->text() == i18n("Progressive");
+    QString vl4ProfilePath = KStandardDirs::locateLocal("appdata", "profiles/video4linux");
+    ProfilesDialog::saveProfile(profile, vl4ProfilePath);
+}
+
+void KdenliveSettingsDialog::slotManageEncodingProfile()
+{
+    int type = 0;
+    if (currentPage() == m_page4) {
+        if (m_configCapture.tabWidget->currentIndex() == 1) type = 1;
+        else if (m_configCapture.tabWidget->currentIndex() == 3) type = 2;
+    }
+    EncodingProfilesDialog *d = new EncodingProfilesDialog(type);
+    d->exec();
+    delete d;
+    loadEncodingProfiles();
+}
+
+void KdenliveSettingsDialog::loadEncodingProfiles()
+{
+    KConfig conf("encodingprofiles.rc", KConfig::FullConfig, "appdata");
+
+    // Load v4l profiles
+    m_configCapture.kcfg_v4l_profile->blockSignals(true);
+    QString currentItem = m_configCapture.kcfg_v4l_profile->currentText();
+    m_configCapture.kcfg_v4l_profile->clear();
+    KConfigGroup group(&conf, "video4linux");
+    QMap< QString, QString > values = group.entryMap();
+    QMapIterator<QString, QString> i(values);
+    while (i.hasNext()) {
+        i.next();
+        if (!i.key().isEmpty()) m_configCapture.kcfg_v4l_profile->addItem(i.key(), i.value());
+    }
+    m_configCapture.kcfg_v4l_profile->blockSignals(false);
+    if (!currentItem.isEmpty()) m_configCapture.kcfg_v4l_profile->setCurrentIndex(m_configCapture.kcfg_v4l_profile->findText(currentItem));
+
+    // Load Decklink profiles
+    m_configCapture.kcfg_decklink_profile->blockSignals(true);
+    currentItem = m_configCapture.kcfg_decklink_profile->currentText();
+    m_configCapture.kcfg_decklink_profile->clear();
+    KConfigGroup group2(&conf, "decklink");
+    values = group2.entryMap();
+    QMapIterator<QString, QString> j(values);
+    while (j.hasNext()) {
+        j.next();
+        if (!j.key().isEmpty()) m_configCapture.kcfg_decklink_profile->addItem(j.key(), j.value());
+    }
+    m_configCapture.kcfg_decklink_profile->blockSignals(false);
+    if (!currentItem.isEmpty()) m_configCapture.kcfg_decklink_profile->setCurrentIndex(m_configCapture.kcfg_decklink_profile->findText(currentItem));
+
+    // Load Proxy profiles
+    m_configProject.kcfg_proxy_profile->blockSignals(true);
+    currentItem = m_configProject.kcfg_proxy_profile->currentText();
+    m_configProject.kcfg_proxy_profile->clear();
+    KConfigGroup group3(&conf, "proxy");
+    values = group3.entryMap();
+    QMapIterator<QString, QString> k(values);
+    while (k.hasNext()) {
+        k.next();
+        if (!k.key().isEmpty()) m_configProject.kcfg_proxy_profile->addItem(k.key(), k.value());
+    }
+    if (!currentItem.isEmpty()) m_configProject.kcfg_proxy_profile->setCurrentIndex(m_configProject.kcfg_proxy_profile->findText(currentItem));
+    m_configProject.kcfg_proxy_profile->blockSignals(false);
+    slotUpdateProxyProfile();
+    
+}
+
+void KdenliveSettingsDialog::slotUpdateDecklinkProfile(int ix)
+{
+    if (ix == -1) ix = KdenliveSettings::decklink_profile();
+    else ix = m_configCapture.kcfg_decklink_profile->currentIndex();
+    QString data = m_configCapture.kcfg_decklink_profile->itemData(ix).toString();
+    if (data.isEmpty()) return;
+    m_configCapture.decklink_parameters->setPlainText(data.section(";", 0, 0));
+    //
+}
+
+void KdenliveSettingsDialog::slotUpdateV4lProfile(int ix)
+{
+    if (ix == -1) ix = KdenliveSettings::v4l_profile();
+    else ix = m_configCapture.kcfg_v4l_profile->currentIndex();
+    QString data = m_configCapture.kcfg_v4l_profile->itemData(ix).toString();
+    if (data.isEmpty()) return;
+    m_configCapture.v4l_parameters->setPlainText(data.section(";", 0, 0));
+    //
+}
+
+void KdenliveSettingsDialog::slotUpdateProxyProfile(int ix)
+{
+    if (ix == -1) ix = KdenliveSettings::v4l_profile();
+    else ix = m_configProject.kcfg_proxy_profile->currentIndex();
+    QString data = m_configProject.kcfg_proxy_profile->itemData(ix).toString();
+    if (data.isEmpty()) return;
+    m_configProject.proxyparams->setPlainText(data.section(";", 0, 0));
+    //
+}
+
+void KdenliveSettingsDialog::slotEditVideo4LinuxProfile()
+{
+    QString vl4ProfilePath = KStandardDirs::locateLocal("appdata", "profiles/video4linux");
+    ProfilesDialog *w = new ProfilesDialog(vl4ProfilePath);
+    if (w->exec() == QDialog::Accepted) {
+        // save and update profile
+        loadCurrentV4lProfileInfo();
+    }
+    delete w;
+}
 
 #include "kdenlivesettingsdialog.moc"
 
