@@ -22,7 +22,9 @@
 
 
 #include "gentime.h"
+#include "renderer.h"
 #include "timecodedisplay.h"
+#include "abstractmonitor.h"
 #if defined(Q_WS_MAC) || defined(USE_OPEN_GL)
 #include "videoglwidget.h"
 #endif
@@ -36,17 +38,14 @@
 #include <KAction>
 #include <KRestrictedLine>
 
-
-class MonitorManager;
-class Render;
 class SmallRuler;
 class DocClipBase;
 class AbstractClipItem;
 class Transition;
 class ClipItem;
 class MonitorEditWidget;
-
 class Monitor;
+class MonitorManager;
 
 class VideoContainer : public QFrame
 {
@@ -75,16 +74,8 @@ public:
     MonitorRefresh(QWidget *parent = 0);
     void setRenderer(Render* render);
 
-protected:
-    virtual void paintEvent(QPaintEvent *event);
-
 private:
     Render *m_renderer;
-
-signals:
-    void switchFullScreen();
-    void switchPlay();
-    void mouseSeek(int, bool);
 };
 
 class Overlay : public QLabel
@@ -106,16 +97,17 @@ signals:
     void editMarker();
 };
 
-class Monitor : public QWidget
+class Monitor : public AbstractMonitor
 {
     Q_OBJECT
 
 public:
     Monitor(QString name, MonitorManager *manager, QString profile = QString(), QWidget *parent = 0);
-    virtual ~Monitor();
+    ~Monitor();
     Render *render;
-    void resetProfile(const QString profile);
-    QString name() const;
+    AbstractRender *abstractRender();
+    void resetProfile(const QString &profile);
+    const QString name() const;
     void resetSize();
     bool isActive() const;
     void pause();
@@ -133,6 +125,7 @@ public:
 protected:
     virtual void mousePressEvent(QMouseEvent * event);
     virtual void mouseReleaseEvent(QMouseEvent * event);
+    virtual void resizeEvent(QResizeEvent *event);
 
     /** @brief Move to another position on mouse wheel event.
      *
@@ -154,7 +147,6 @@ private:
     DocClipBase *m_currentClip;
     SmallRuler *m_ruler;
     Overlay *m_overlay;
-    bool m_isActive;
     double m_scale;
     int m_length;
     bool m_dragStarted;
@@ -177,6 +169,7 @@ private:
     /** true if selected clip is transition, false = selected clip is clip.
      *  Necessary because sometimes we get two signals, e.g. we get a clip and we get selected transition = NULL. */
     bool m_loopClipTransition;
+
 #if defined(Q_WS_MAC) || defined(USE_OPEN_GL)
     VideoGLWidget *m_glWidget;
     bool createOpenGlWidget(QWidget *parent, const QString profile);
@@ -208,13 +201,14 @@ private slots:
 
 public slots:
     void slotOpenFile(const QString &);
-    void slotSetXml(DocClipBase *clip, QPoint zone = QPoint(), const int position = -1);
+    void slotSetClipProducer(DocClipBase *clip, QPoint zone = QPoint(), int position = -1);
+    void updateClipProducer(Mlt::Producer *prod);
     void refreshMonitor(bool visible);
     void refreshMonitor();
     void slotSeek(int pos);
     void stop();
     void start();
-    void activateMonitor();
+    bool activateMonitor();
     void slotPlay();
     void slotPlayZone();
     void slotLoopZone();
@@ -253,7 +247,7 @@ signals:
     void refreshClipThumbnail(const QString &, bool);
     void adjustMonitorSize();
     void zoneUpdated(QPoint);
-    void saveZone(Render *, QPoint);
+    void saveZone(Render *, QPoint, DocClipBase *);
     /** @brief  Editing transitions / effects over the monitor requires the renderer to send frames as QImage.
      *      This causes a major slowdown, so we only enable it if required */
     void requestFrameForAnalysis(bool);
