@@ -31,6 +31,7 @@
 
 #include "gentime.h"
 #include "definitions.h"
+#include "abstractmonitor.h"
 #include "mlt/framework/mlt_types.h"
 
 #include <kurl.h>
@@ -40,9 +41,8 @@
 #include <qmap.h>
 #include <QList>
 #include <QEvent>
-
-
-class Render;
+#include <QMutex>
+#include <QFuture>
 
 class QTimer;
 class QPixmap;
@@ -59,6 +59,19 @@ class Producer;
 class Filter;
 class Profile;
 class Service;
+class Event;
+};
+
+struct requestClipInfo {
+    QDomElement xml;
+    QString clipId;
+    int imageHeight;
+    bool replaceProducer;
+
+bool operator==(const requestClipInfo &a)
+{
+    return clipId == a.clipId;
+}
 };
 
 class MltErrorEvent : public QEvent
@@ -73,7 +86,8 @@ private:
     QString m_message;
 };
 
-class Render: public QObject
+
+class Render: public AbstractRender
 {
 Q_OBJECT public:
 
@@ -84,17 +98,15 @@ Q_OBJECT public:
      *  @param rendererName A unique identifier for this renderer
      *  @param winid The parent widget identifier (required for SDL display). Set to 0 for OpenGL rendering
      *  @param profile The MLT profile used for the renderer (default one will be used if empty). */
-    Render(const QString & rendererName, int winid, QString profile = QString(), QWidget *parent = 0);
+    Render(const QString &rendererName, int winid, QString profile = QString(), QWidget *parent = 0);
 
     /** @brief Destroy the MLT Renderer. */
-    ~Render();
+    virtual ~Render();
 
     /** @brief Seeks the renderer clip to the given time. */
     void seek(GenTime time);
     void seek(int time);
-    void seekToFrame(int pos);
     void seekToFrameDiff(int diff);
-    int m_isBlocked;
 
     QPixmap getImageThumbnail(KUrl url, int width, int height);
 
@@ -123,12 +135,12 @@ Q_OBJECT public:
      * The speed is relative to normal playback, e.g. 1.0 is normal speed, 0.0
      * is paused, -1.0 means play backwards. It does not specify start/stop */
     void play(double speed);
-    void switchPlay();
+    void switchPlay(bool play);
     void pause();
 
     /** @brief Stops playing.
      * @param startTime time to seek to */
-    void stop(const GenTime & startTime);
+    void stop(const GenTime &startTime);
     int volume() const;
 
     QImage extractFrame(int frame_position, QString path = QString(), int width = -1, int height = -1);
@@ -147,14 +159,14 @@ Q_OBJECT public:
     /** @brief Returns the speed at which the renderer is currently playing.
      *
      * It returns 0.0 when the renderer is not playing anything. */
-    double playSpeed();
+    double playSpeed() const;
 
     /** @brief Returns the current seek position of the renderer. */
     GenTime seekPosition() const;
     int seekFramePosition() const;
 
     void emitFrameUpdated(Mlt::Frame&);
-    void emitFrameNumber(double position);
+    void emitFrameNumber();
     void emitConsumerStopped();
 
     /** @brief Returns the aspect ratio of the consumer. */
@@ -165,9 +177,14 @@ Q_OBJECT public:
     /** @brief Saves current producer frame as an image. */
     void exportCurrentFrame(KUrl url, bool notify);
 
-    /** @brief Turns on or off on screen display. */
-    void refreshDisplay();
-    int resetProfile(const QString profileName);
+    /** @brief Change the Mlt PROFILE
+     * @param profileName The MLT profile name
+     * @param dropSceneList If true, the current playlist will be deleted
+     * @return true if the profile was changed
+     * . */
+    int resetProfile(const QString& profileName, bool dropSceneList = false);
+    /** @brief Returns true if the render uses profileName as current profile. */
+    bool hasProfile(const QString& profileName) const;
     double fps() const;
 
     /** @brief Returns the width of a frame for this profile. */
@@ -187,10 +204,10 @@ Q_OBJECT public:
      */
     Mlt::Producer *checkSlowMotionProducer(Mlt::Producer *prod, QDomElement element);
     int mltInsertClip(ItemInfo info, QDomElement element, Mlt::Producer *prod, bool overwrite = false, bool push = false);
-    bool mltUpdateClip(ItemInfo info, QDomElement element, Mlt::Producer *prod);
+    bool mltUpdateClip(Mlt::Tractor *tractor, ItemInfo info, QDomElement element, Mlt::Producer *prod);
     void mltCutClip(int track, GenTime position);
-    void mltInsertSpace(QMap <int, int> trackClipStartList, QMap <int, int> trackTransitionStartList, int track, const GenTime duration, const GenTime timeOffset);
-    int mltGetSpaceLength(const GenTime pos, int track, bool fromBlankStart);
+    void mltInsertSpace(QMap <int, int> trackClipStartList, QMap <int, int> trackTransitionStartList, int track, const GenTime &duration, const GenTime &timeOffset);
+    int mltGetSpaceLength(const GenTime &pos, int track, bool fromBlankStart);
 
     /** @brief Returns the duration/length of @param track as reported by the track producer. */
     int mltTrackDuration(int track);
@@ -203,8 +220,8 @@ Q_OBJECT public:
     bool mltRemoveClip(int track, GenTime position);
 
     /** @brief Deletes an effect from a clip in MLT's playlist. */
-    bool mltRemoveEffect(int track, GenTime position, QString index, bool updateIndex, bool doRefresh = true);
-    bool mltRemoveTrackEffect(int track, QString index, bool updateIndex);
+    bool mltRemoveEffect(int track, GenTime position, int index, bool updateIndex, bool doRefresh = true);
+    bool mltRemoveTrackEffect(int track, int index, bool updateIndex);
 
     /** @brief Adds an effect to a clip in MLT's playlist. */
     bool mltAddEffect(int track, GenTime position, EffectsParameterList params, bool doRefresh = true);
@@ -238,7 +255,7 @@ Q_OBJECT public:
     void mltResizeTransparency(int oldStart, int newStart, int newEnd, int track, int id);
     void mltInsertTrack(int ix, bool videoTrack);
     void mltDeleteTrack(int ix);
-    bool mltUpdateClipProducer(int track, int pos, Mlt::Producer *prod);
+    bool mltUpdateClipProducer(Mlt::Tractor *tractor, int track, int pos, Mlt::Producer *prod);
     void mltPlantTransition(Mlt::Field *field, Mlt::Transition &tr, int a_track, int b_track);
     Mlt::Producer *invalidProducer(const QString &id);
 
@@ -261,11 +278,31 @@ Q_OBJECT public:
     void showAudio(Mlt::Frame&);
     /** @brief This property is used to decide if the renderer should send audio data for monitoring. */
     bool analyseAudio;
-    /** @brief This property is used to decide if the renderer should convert it's frames to QImage for use in other Kdenlive widgets. */
-    bool sendFrameForAnalysis;
+    
     QList <int> checkTrackSequence(int);
     void sendFrameUpdate();
 
+    /** @brief Returns a pointer to the main producer. */
+    Mlt::Producer *getProducer();
+    /** @brief Returns the number of clips to process (When requesting clip info). */
+    int processingItems() const;
+    /** @brief Force processing of clip with selected id. */
+    void forceProcessing(const QString &id);
+    /** @brief Are we currently processing clip with selected id. */
+    bool isProcessing(const QString &id);
+
+    /** @brief Requests the file properties for the specified URL (will be put in a queue list)
+        @param xml The xml parameters for the clip
+        @param clipId The clip Id string
+        @param imageHeight The height (in pixels) of the returned thumbnail (height of a treewidgetitem in projectlist)
+        @param replaceProducer If true, the MLT producer will be recreated */
+    void getFileProperties(const QDomElement &xml, const QString &clipId, int imageHeight, bool replaceProducer = true);
+
+    /** @brief Lock the MLT service */
+    Mlt::Tractor *lockService();
+    /** @brief Unlock the MLT service */
+    void unlockService(Mlt::Tractor *tractor);
+
 private:
 
     /** @brief The name of this renderer.
@@ -276,7 +313,8 @@ private:
     Mlt::Consumer * m_mltConsumer;
     Mlt::Producer * m_mltProducer;
     Mlt::Profile *m_mltProfile;
-    double m_framePosition;
+    Mlt::Event *m_showFrameEvent;
+    Mlt::Event *m_pauseEvent;
     double m_fps;
     bool m_externalConsumer;
 
@@ -296,19 +334,28 @@ private:
     QString m_activeProfile;
 
     QTimer *m_osdTimer;
+    QTimer m_refreshTimer;
+    QMutex m_mutex;
+    QMutex m_infoMutex;
 
     /** @brief A human-readable description of this renderer. */
     int m_winid;
 
+    QLocale m_locale;
+    QFuture <void> m_infoThread;
+    QList <requestClipInfo> m_requestList;
+
     void closeMlt();
     void mltCheckLength(Mlt::Tractor *tractor);
     void mltPasteEffects(Mlt::Producer *source, Mlt::Producer *dest);
     QMap<QString, QString> mltGetTransitionParamsFromXml(QDomElement xml);
     QMap<QString, Mlt::Producer *> m_slowmotionProducers;
+    /** @brief The id of the clip that is currently being loaded for info query */
+    QString m_processingClipId;
 
     /** @brief Build the MLT Consumer object with initial settings.
      *  @param profileName The MLT profile to use for the consumer */
-    void buildConsumer(const QString profileName);
+    void buildConsumer(const QString& profileName);
     void resetZoneMode();
     void fillSlowMotionProducers();
     /** @brief Get the track number of the lowest audible (non muted) audio track
@@ -317,22 +364,25 @@ private:
 
     /** @brief Make sure our audio mixing transitions are applied to the lowest track */
     void fixAudioMixing(Mlt::Tractor tractor);
+    /** @brief Make sure we inform MLT if we need a lot of threads for avformat producer */
+    void checkMaxThreads();
 
 private slots:
 
     /** @brief Refreshes the monitor display. */
     void refresh();
     void slotOsdTimeout();
-    int connectPlaylist();
-    //void initSceneList();
+    /** @brief Process the clip info requests (in a separate thread). */
+    void processFileProperties();
 
 signals:
 
     /** @brief The renderer received a reply to a getFileProperties request. */
-    void replyGetFileProperties(const QString &clipId, Mlt::Producer*, const QMap < QString, QString > &, const QMap < QString, QString > &, bool, bool);
+    void replyGetFileProperties(const QString &clipId, Mlt::Producer*, const stringMap &, const stringMap &, bool replaceProducer);
 
     /** @brief The renderer received a reply to a getImage request. */
-    void replyGetImage(const QString &, const QPixmap &);
+    void replyGetImage(const QString &, const QString &, int, int);
+    void replyGetImage(const QString &, const QImage &);
 
     /** @brief The renderer stopped, either playing or rendering. */
     void stopped();
@@ -355,17 +405,13 @@ signals:
      *  @param durationError Should be set to true if the proxy failed because it has not same length as original clip
      */
     void removeInvalidProxy(const QString &id, bool durationError);
-    void refreshDocumentProducers();
+    void refreshDocumentProducers(bool displayRatioChanged, bool fpsChanged);
 
     /** @brief A frame's image has to be shown.
      *
      * Used in Mac OS X. */
     void showImageSignal(QImage);
-    void showAudioSignal(const QByteArray);
-    /** @brief The renderer refreshed the current frame, but no seeking was done. */
-    void frameUpdated(QImage);
-    /** @brief This signal contains the audio of the current frame. */
-    void audioSamplesSignal(const QVector<int16_t>&, int freq, int num_channels, int num_samples);
+    void showAudioSignal(const QByteArray &);
 
 public slots:
 
@@ -379,21 +425,12 @@ public slots:
     /** @brief Checks if the file is readable by MLT. */
     bool isValid(KUrl url);
 
-    /** @brief Requests the file properties for the specified URL.
-        @param xml The xml parameters for the clip
-        @param clipId The clip Id string
-        @param imageHeight The height (in pixels) of the returned thumbnail (height of a treewidgetitem in projectlist)
-        @param replaceProducer If true, the MLT producer will be recreated
-        @param selectClip If true, clip item will be selected in project view
-     * Upon return, the result will be emitted via replyGetFileProperties().
-     * Wraps the VEML command of the same name. */
-    void getFileProperties(const QDomElement xml, const QString &clipId, int imageHeight, bool replaceProducer = true, bool selectClip = false);
-
     void exportFileToFirewire(QString srcFileName, int port, GenTime startTime, GenTime endTime);
     void mltSavePlaylist();
     void slotSplitView(bool doit);
     void slotSwitchFullscreen();
     void slotSetVolume(int volume);
+    void seekToFrame(int pos);
 };
 
 #endif
