@@ -137,13 +137,13 @@ QString Timecode::reformatSeparators(QString duration) const
     return duration.replace(8, 1, ':');
 }
 
-int Timecode::getDisplayFrameCount(const QString duration, bool frameDisplay) const
+int Timecode::getDisplayFrameCount(const QString &duration, bool frameDisplay) const
 {
     if (frameDisplay) return duration.toInt();
     return getFrameCount(duration);
 }
 
-int Timecode::getFrameCount(const QString duration) const
+int Timecode::getFrameCount(const QString &duration) const
 {
     if (m_dropFrameTimecode) {
 
@@ -374,12 +374,13 @@ const QString Timecode::getTimecodeHH_MM_SS_HH(const GenTime & time) const
 
 const QString Timecode::getTimecodeFrames(const GenTime & time) const
 {
-    return QString::number(time.frames(m_realFps));
+    return QString::number((int) time.frames(m_realFps));
 }
 
 const QString Timecode::getTimecodeSeconds(const GenTime & time) const
 {
-    return QString::number(time.seconds());
+    QLocale locale;
+    return locale.toString(time.seconds());
 }
 
 const QString Timecode::getTimecodeDropFrame(const GenTime & time) const
