@@ -76,6 +76,9 @@ public:
     * Parses all tracks to check if there is audio data. */
     bool checkProjectAudio() const;
 
+    void checkTrackHeight();
+    void updateProfile();
+
 protected:
     virtual void keyPressEvent(QKeyEvent * event);
 
@@ -84,7 +87,8 @@ public slots:
     void slotChangeZoom(int horizontal, int vertical = -1);
     void setDuration(int dur);
     void slotSetZone(QPoint p, bool updateDocumentProperties = true);
-
+    /** @brief Save a snapshot image of current timeline view */
+    void slotSaveTimelinePreview(const QString path);
 private:
     CustomRuler *m_ruler;
     CustomTrackView *m_trackview;
@@ -93,14 +97,17 @@ private:
     int m_projectTracks;
     QString m_editMode;
     CustomTrackScene *m_scene;
+    /** @brief A list of producer ids to be replaced when opening a corrupted document*/
+    QMap <QString, QString> m_replacementProducerIds;
 
     KdenliveDoc *m_doc;
     int m_verticalZoom;
     QString m_documentErrors;
     void parseDocument(QDomDocument doc);
-    int slotAddProjectTrack(int ix, QDomElement xml, bool locked);
+    int slotAddProjectTrack(int ix, QDomElement xml, bool locked, QDomNodeList producers);
     DocClipBase *getMissingProducer(const QString id) const;
     void adjustTrackHeaders();
+    /** @brief Add effects from the xml. Returns true if some effect was upgraded, false if everything went fine.*/
     void slotAddProjectEffects(QDomNodeList effects, QDomElement parentNode, ClipItem *clip, int trackIndex);
 
 private slots:
